"""
Python module generated from Java source file org.bukkit.event.inventory.InventoryAction

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.event.inventory import *
from typing import Any, Callable, Iterable, Tuple


class InventoryAction(Enum):
    """
    An estimation of what the result will be.
    """

    NOTHING = 0
    """
    Nothing will happen from the click.
    
    There may be cases where nothing will happen and this is value is not
    provided, but it is guaranteed that this value is accurate when given.
    """
    PICKUP_ALL = 1
    """
    All of the items on the clicked slot are moved to the cursor.
    """
    PICKUP_SOME = 2
    """
    Some of the items on the clicked slot are moved to the cursor.
    """
    PICKUP_HALF = 3
    """
    Half of the items on the clicked slot are moved to the cursor.
    """
    PICKUP_ONE = 4
    """
    One of the items on the clicked slot are moved to the cursor.
    """
    PLACE_ALL = 5
    """
    All of the items on the cursor are moved to the clicked slot.
    """
    PLACE_SOME = 6
    """
    Some of the items from the cursor are moved to the clicked slot
    (usually up to the max stack size).
    """
    PLACE_ONE = 7
    """
    A single item from the cursor is moved to the clicked slot.
    """
    SWAP_WITH_CURSOR = 8
    """
    The clicked item and the cursor are exchanged.
    """
    DROP_ALL_CURSOR = 9
    """
    The entire cursor item is dropped.
    """
    DROP_ONE_CURSOR = 10
    """
    One item is dropped from the cursor.
    """
    DROP_ALL_SLOT = 11
    """
    The entire clicked slot is dropped.
    """
    DROP_ONE_SLOT = 12
    """
    One item is dropped from the clicked slot.
    """
    MOVE_TO_OTHER_INVENTORY = 13
    """
    The item is moved to the opposite inventory if a space is found.
    """
    HOTBAR_MOVE_AND_READD = 14
    """
    The clicked item is moved to the hotbar, and the item currently there
    is re-added to the player's inventory.
    
    The hotbar includes the player's off hand.
    """
    HOTBAR_SWAP = 15
    """
    The clicked slot and the picked hotbar slot are swapped.
    
    The hotbar includes the player's off hand.
    """
    CLONE_STACK = 16
    """
    A max-size stack of the clicked item is put on the cursor.
    """
    COLLECT_TO_CURSOR = 17
    """
    The inventory is searched for the same material, and they are put on
    the cursor up to org.bukkit.Material.getMaxStackSize().
    """
    UNKNOWN = 18
    """
    An unrecognized ClickType.
    """



"""
Python module generated from Java source file org.bukkit.event.block.CauldronLevelChangeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from enum import Enum
from org.bukkit import Material
from org.bukkit.block import Block
from org.bukkit.block import BlockState
from org.bukkit.block.data import BlockData
from org.bukkit.block.data import Levelled
from org.bukkit.entity import Entity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class CauldronLevelChangeEvent(BlockEvent, Cancellable):

    def __init__(self, block: "Block", entity: "Entity", reason: "ChangeReason", newBlock: "BlockState"):
        ...


    def getEntity(self) -> "Entity":
        """
        Get entity which did this. May be null.

        Returns
        - acting entity
        """
        ...


    def getReason(self) -> "ChangeReason":
        ...


    def getNewState(self) -> "BlockState":
        """
        Gets the new state of the cauldron.

        Returns
        - The block state of the block that will be changed
        """
        ...


    def getOldLevel(self) -> int:
        """
        Gets the old level of the cauldron.

        Returns
        - old level

        See
        - .getBlock()

        Deprecated
        - not all cauldron contents are Levelled
        """
        ...


    def getNewLevel(self) -> int:
        """
        Gets the new level of the cauldron.

        Returns
        - new level

        See
        - .getNewState()

        Deprecated
        - not all cauldron contents are Levelled
        """
        ...


    def setNewLevel(self, newLevel: int) -> None:
        """
        Sets the new level of the cauldron.

        Arguments
        - newLevel: new level

        See
        - .getNewState()

        Deprecated
        - not all cauldron contents are Levelled
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancelled: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class ChangeReason(Enum):

        BUCKET_FILL = 0
        """
        Player emptying the cauldron by filling their bucket.
        """
        BUCKET_EMPTY = 1
        """
        Player filling the cauldron by emptying their bucket.
        """
        BOTTLE_FILL = 2
        """
        Player emptying the cauldron by filling their bottle.
        """
        BOTTLE_EMPTY = 3
        """
        Player filling the cauldron by emptying their bottle.
        """
        BANNER_WASH = 4
        """
        Player cleaning their banner.
        """
        ARMOR_WASH = 5
        """
        Player cleaning their armor.
        """
        SHULKER_WASH = 6
        """
        Player cleaning a shulker box.
        """
        EXTINGUISH = 7
        """
        Entity being extinguished.
        """
        EVAPORATE = 8
        """
        Evaporating due to biome dryness.
        """
        NATURAL_FILL = 9
        """
        Filling due to natural fluid sources, eg rain or dripstone.
        """
        UNKNOWN = 10
        """
        Unknown.
        """



"""
Python module generated from Java source file org.bukkit.event.world.WorldInitEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import World
from org.bukkit.event import HandlerList
from org.bukkit.event.world import *
from typing import Any, Callable, Iterable, Tuple


class WorldInitEvent(WorldEvent):
    """
    Called when a World is initializing.
    
    To get every world it is recommended to add following to the plugin.yml.
    ```load: STARTUP```
    """

    def __init__(self, world: "World"):
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.potion.PotionBrewer

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.potion import *
from typing import Any, Callable, Iterable, Tuple


class PotionBrewer:
    """
    Represents a brewer that can create PotionEffects.
    """

    def createEffect(self, potion: "PotionEffectType", duration: int, amplifier: int) -> "PotionEffect":
        """
        Creates a PotionEffect from the given PotionEffectType,
        applying duration modifiers and checks.

        Arguments
        - potion: The type of potion
        - duration: The duration in ticks
        - amplifier: The amplifier of the effect

        Returns
        - The resulting potion effect
        """
        ...


    def getEffectsFromDamage(self, damage: int) -> Iterable["PotionEffect"]:
        """
        Returns a collection of PotionEffect that would be applied from
        a potion with the given data value.

        Arguments
        - damage: The data value of the potion

        Returns
        - The list of effects

        Deprecated
        - Non-Functional
        """
        ...


    def getEffects(self, type: "PotionType", upgraded: bool, extended: bool) -> Iterable["PotionEffect"]:
        """
        Returns a collection of PotionEffect that would be applied from
        a potion with the given type.

        Arguments
        - type: The type of the potion
        - upgraded: Whether the potion is upgraded
        - extended: Whether the potion is extended

        Returns
        - The list of effects

        Deprecated
        - Upgraded / extended potions are now their own PotionType use PotionType.getPotionEffects() instead
        """
        ...



"""
Python module generated from Java source file org.bukkit.configuration.MemorySection

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.base import Strings
from java.util import Collections
from java.util import LinkedHashSet
from org.bukkit import Color
from org.bukkit import Location
from org.bukkit import OfflinePlayer
from org.bukkit.configuration import *
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.inventory import ItemStack
from org.bukkit.util import Vector
from typing import Any, Callable, Iterable, Tuple


class MemorySection(ConfigurationSection):
    """
    A type of ConfigurationSection that is stored in memory.
    """

    def getKeys(self, deep: bool) -> set[str]:
        ...


    def getValues(self, deep: bool) -> dict[str, "Object"]:
        ...


    def contains(self, path: str) -> bool:
        ...


    def contains(self, path: str, ignoreDefault: bool) -> bool:
        ...


    def isSet(self, path: str) -> bool:
        ...


    def getCurrentPath(self) -> str:
        ...


    def getName(self) -> str:
        ...


    def getRoot(self) -> "Configuration":
        ...


    def getParent(self) -> "ConfigurationSection":
        ...


    def addDefault(self, path: str, value: "Object") -> None:
        ...


    def getDefaultSection(self) -> "ConfigurationSection":
        ...


    def set(self, path: str, value: "Object") -> None:
        ...


    def get(self, path: str) -> "Object":
        ...


    def get(self, path: str, def: "Object") -> "Object":
        ...


    def createSection(self, path: str) -> "ConfigurationSection":
        ...


    def createSection(self, path: str, map: dict[Any, Any]) -> "ConfigurationSection":
        ...


    def getString(self, path: str) -> str:
        ...


    def getString(self, path: str, def: str) -> str:
        ...


    def isString(self, path: str) -> bool:
        ...


    def getInt(self, path: str) -> int:
        ...


    def getInt(self, path: str, def: int) -> int:
        ...


    def isInt(self, path: str) -> bool:
        ...


    def getBoolean(self, path: str) -> bool:
        ...


    def getBoolean(self, path: str, def: bool) -> bool:
        ...


    def isBoolean(self, path: str) -> bool:
        ...


    def getDouble(self, path: str) -> float:
        ...


    def getDouble(self, path: str, def: float) -> float:
        ...


    def isDouble(self, path: str) -> bool:
        ...


    def getLong(self, path: str) -> int:
        ...


    def getLong(self, path: str, def: int) -> int:
        ...


    def isLong(self, path: str) -> bool:
        ...


    def getList(self, path: str) -> list[Any]:
        ...


    def getList(self, path: str, def: list[Any]) -> list[Any]:
        ...


    def isList(self, path: str) -> bool:
        ...


    def getStringList(self, path: str) -> list[str]:
        ...


    def getIntegerList(self, path: str) -> list["Integer"]:
        ...


    def getBooleanList(self, path: str) -> list["Boolean"]:
        ...


    def getDoubleList(self, path: str) -> list["Double"]:
        ...


    def getFloatList(self, path: str) -> list["Float"]:
        ...


    def getLongList(self, path: str) -> list["Long"]:
        ...


    def getByteList(self, path: str) -> list["Byte"]:
        ...


    def getCharacterList(self, path: str) -> list["Character"]:
        ...


    def getShortList(self, path: str) -> list["Short"]:
        ...


    def getMapList(self, path: str) -> list[dict[Any, Any]]:
        ...


    def getObject(self, path: str, clazz: type["T"]) -> "T":
        ...


    def getObject(self, path: str, clazz: type["T"], def: "T") -> "T":
        ...


    def getSerializable(self, path: str, clazz: type["T"]) -> "T":
        ...


    def getSerializable(self, path: str, clazz: type["T"], def: "T") -> "T":
        ...


    def getVector(self, path: str) -> "Vector":
        ...


    def getVector(self, path: str, def: "Vector") -> "Vector":
        ...


    def isVector(self, path: str) -> bool:
        ...


    def getOfflinePlayer(self, path: str) -> "OfflinePlayer":
        ...


    def getOfflinePlayer(self, path: str, def: "OfflinePlayer") -> "OfflinePlayer":
        ...


    def isOfflinePlayer(self, path: str) -> bool:
        ...


    def getItemStack(self, path: str) -> "ItemStack":
        ...


    def getItemStack(self, path: str, def: "ItemStack") -> "ItemStack":
        ...


    def isItemStack(self, path: str) -> bool:
        ...


    def getColor(self, path: str) -> "Color":
        ...


    def getColor(self, path: str, def: "Color") -> "Color":
        ...


    def isColor(self, path: str) -> bool:
        ...


    def getLocation(self, path: str) -> "Location":
        ...


    def getLocation(self, path: str, def: "Location") -> "Location":
        ...


    def isLocation(self, path: str) -> bool:
        ...


    def getConfigurationSection(self, path: str) -> "ConfigurationSection":
        ...


    def isConfigurationSection(self, path: str) -> bool:
        ...


    @staticmethod
    def createPath(section: "ConfigurationSection", key: str) -> str:
        """
        Creates a full path to the given ConfigurationSection from its
        root Configuration.
        
        You may use this method for any given ConfigurationSection, not
        only MemorySection.

        Arguments
        - section: Section to create a path for.
        - key: Name of the specified section.

        Returns
        - Full path of the section from its root.
        """
        ...


    @staticmethod
    def createPath(section: "ConfigurationSection", key: str, relativeTo: "ConfigurationSection") -> str:
        """
        Creates a relative path to the given ConfigurationSection from
        the given relative section.
        
        You may use this method for any given ConfigurationSection, not
        only MemorySection.

        Arguments
        - section: Section to create a path for.
        - key: Name of the specified section.
        - relativeTo: Section to create the path relative to.

        Returns
        - Full path of the section from its root.
        """
        ...


    def getComments(self, path: str) -> list[str]:
        ...


    def getInlineComments(self, path: str) -> list[str]:
        ...


    def setComments(self, path: str, comments: list[str]) -> None:
        ...


    def setInlineComments(self, path: str, comments: list[str]) -> None:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.block.BlockFace

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block import *
from org.bukkit.util import Vector
from typing import Any, Callable, Iterable, Tuple


class BlockFace(Enum):
    """
    Represents the face of a block
    """

    NORTH = (0, 0, -1)
    EAST = (1, 0, 0)
    SOUTH = (0, 0, 1)
    WEST = (-1, 0, 0)
    UP = (0, 1, 0)
    DOWN = (0, -1, 0)
    NORTH_EAST = (NORTH, EAST)
    NORTH_WEST = (NORTH, WEST)
    SOUTH_EAST = (SOUTH, EAST)
    SOUTH_WEST = (SOUTH, WEST)
    WEST_NORTH_WEST = (WEST, NORTH_WEST)
    NORTH_NORTH_WEST = (NORTH, NORTH_WEST)
    NORTH_NORTH_EAST = (NORTH, NORTH_EAST)
    EAST_NORTH_EAST = (EAST, NORTH_EAST)
    EAST_SOUTH_EAST = (EAST, SOUTH_EAST)
    SOUTH_SOUTH_EAST = (SOUTH, SOUTH_EAST)
    SOUTH_SOUTH_WEST = (SOUTH, SOUTH_WEST)
    WEST_SOUTH_WEST = (WEST, SOUTH_WEST)
    SELF = (0, 0, 0)


    def getModX(self) -> int:
        """
        Get the amount of X-coordinates to modify to get the represented block

        Returns
        - Amount of X-coordinates to modify
        """
        ...


    def getModY(self) -> int:
        """
        Get the amount of Y-coordinates to modify to get the represented block

        Returns
        - Amount of Y-coordinates to modify
        """
        ...


    def getModZ(self) -> int:
        """
        Get the amount of Z-coordinates to modify to get the represented block

        Returns
        - Amount of Z-coordinates to modify
        """
        ...


    def getDirection(self) -> "Vector":
        """
        Gets the normal vector corresponding to this block face.

        Returns
        - the normal vector
        """
        ...


    def isCartesian(self) -> bool:
        """
        Returns True if this face is aligned with one of the unit axes in 3D
        Cartesian space (ie NORTH, SOUTH, EAST, WEST, UP, DOWN).

        Returns
        - Cartesian status
        """
        ...


    def getOppositeFace(self) -> "BlockFace":
        ...



from .EntityBlockFormEvent import EntityBlockFormEvent
from .BlockCookEvent import BlockCookEvent
from .Action import Action
from .BlockPistonExtendEvent import BlockPistonExtendEvent
from .BellRingEvent import BellRingEvent
from .BrewingStartEvent import BrewingStartEvent
from .BlockEvent import BlockEvent
from .TNTPrimeEvent import TNTPrimeEvent
from .BlockExplodeEvent import BlockExplodeEvent
from .BlockFertilizeEvent import BlockFertilizeEvent
from .MoistureChangeEvent import MoistureChangeEvent
from .BlockDamageAbortEvent import BlockDamageAbortEvent
from .BlockDispenseArmorEvent import BlockDispenseArmorEvent
from .FluidLevelChangeEvent import FluidLevelChangeEvent
from .BlockShearEntityEvent import BlockShearEntityEvent
from .CrafterCraftEvent import CrafterCraftEvent
from .BellResonateEvent import BellResonateEvent
from .BlockIgniteEvent import BlockIgniteEvent
from .LeavesDecayEvent import LeavesDecayEvent
from .BlockFadeEvent import BlockFadeEvent
from .BlockPhysicsEvent import BlockPhysicsEvent
from .BlockExpEvent import BlockExpEvent
from .BlockGrowEvent import BlockGrowEvent
from .BlockPlaceEvent import BlockPlaceEvent
from .BlockReceiveGameEvent import BlockReceiveGameEvent
from .VaultDisplayItemEvent import VaultDisplayItemEvent
from .BlockMultiPlaceEvent import BlockMultiPlaceEvent
from .BlockCanBuildEvent import BlockCanBuildEvent
from .CauldronLevelChangeEvent import CauldronLevelChangeEvent
from .BlockBurnEvent import BlockBurnEvent
from .SculkBloomEvent import SculkBloomEvent
from .CampfireStartEvent import CampfireStartEvent
from .BlockDispenseLootEvent import BlockDispenseLootEvent
from .SignChangeEvent import SignChangeEvent
from .BlockFormEvent import BlockFormEvent
from .BlockPistonRetractEvent import BlockPistonRetractEvent
from .NotePlayEvent import NotePlayEvent
from .SpongeAbsorbEvent import SpongeAbsorbEvent
from .BlockDispenseEvent import BlockDispenseEvent
from .BlockFromToEvent import BlockFromToEvent
from .BlockSpreadEvent import BlockSpreadEvent
from .BlockDamageEvent import BlockDamageEvent
from .BlockPistonEvent import BlockPistonEvent
from .InventoryBlockStartEvent import InventoryBlockStartEvent
from .BlockDropItemEvent import BlockDropItemEvent
from .BlockRedstoneEvent import BlockRedstoneEvent
from .BlockBreakEvent import BlockBreakEvent


"""
Python module generated from Java source file org.bukkit.Input

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class Input:
    """
    Represents a movement input applied to an entity.
    """

    def isForward(self) -> bool:
        """
        Gets whether a forward input is applied.

        Returns
        - forward input
        """
        ...


    def isBackward(self) -> bool:
        """
        Gets whether a backward input is applied.

        Returns
        - backward input
        """
        ...


    def isLeft(self) -> bool:
        """
        Gets whether a left input is applied.

        Returns
        - left input
        """
        ...


    def isRight(self) -> bool:
        """
        Gets whether a right input is applied.

        Returns
        - right input
        """
        ...


    def isJump(self) -> bool:
        """
        Gets whether a jump input is applied.

        Returns
        - jump input
        """
        ...


    def isSneak(self) -> bool:
        """
        Gets whether a sneak input is applied.

        Returns
        - sneak input
        """
        ...


    def isSprint(self) -> bool:
        """
        Gets whether a sprint input is applied.

        Returns
        - sprint input
        """
        ...



"""
Python module generated from Java source file com.google.gson.stream.MalformedJsonException

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import Strictness
from com.google.gson.stream import *
from java.io import IOException
from typing import Any, Callable, Iterable, Tuple


class MalformedJsonException(IOException):
    """
    Thrown when a reader encounters malformed JSON. Some syntax errors can be ignored by using Strictness.LENIENT for JsonReader.setStrictness(Strictness).
    """

    def __init__(self, msg: str):
        ...


    def __init__(self, msg: str, throwable: "Throwable"):
        ...


    def __init__(self, throwable: "Throwable"):
        ...



from .Condition import Condition
from .Lock import Lock
from .ReadWriteLock import ReadWriteLock
from .ReentrantLock import ReentrantLock
from .ReentrantReadWriteLock import ReentrantReadWriteLock
from .LockSupport import LockSupport
from .AbstractOwnableSynchronizer import AbstractOwnableSynchronizer


"""
Python module generated from Java source file org.bukkit.block.BrewingStand

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import *
from org.bukkit.inventory import BrewerInventory
from typing import Any, Callable, Iterable, Tuple


class BrewingStand(Container):
    """
    Represents a captured state of a brewing stand.
    """

    def getBrewingTime(self) -> int:
        """
        How much time is left in the brewing cycle.

        Returns
        - Brew Time
        """
        ...


    def setBrewingTime(self, brewTime: int) -> None:
        """
        Set the time left before brewing completes.

        Arguments
        - brewTime: Brewing time
        """
        ...


    def getFuelLevel(self) -> int:
        """
        Get the level of current fuel for brewing.

        Returns
        - The fuel level
        """
        ...


    def setFuelLevel(self, level: int) -> None:
        """
        Set the level of current fuel for brewing.

        Arguments
        - level: fuel level
        """
        ...


    def getInventory(self) -> "BrewerInventory":
        ...


    def getSnapshotInventory(self) -> "BrewerInventory":
        ...



"""
Python module generated from Java source file com.google.gson.reflect.TypeToken

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal import $Gson$Types
from com.google.gson.internal import TroubleshootingGuide
from com.google.gson.reflect import *
from java.lang.reflect import GenericArrayType
from java.lang.reflect import ParameterizedType
from java.lang.reflect import Type
from java.lang.reflect import TypeVariable
from java.lang.reflect import WildcardType
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class TypeToken:
    """
    Represents a generic type `T`. Java doesn't yet provide a way to represent generic types,
    so this class does. Forces clients to create a subclass of this class which enables retrieval the
    type information even at runtime.
    
    For example, to create a type literal for `List<String>`, you can create an empty
    anonymous class:
    
    `TypeToken<List<String>> list = new TypeToken<List<String>>() {`;}
    
    Capturing a type variable as type argument of an anonymous `TypeToken` subclass is not
    allowed, for example `TypeToken<List<T>>`. Due to type erasure the runtime type of a type
    variable is not available to Gson and therefore it cannot provide the functionality one might
    expect. This would give a False sense of type-safety at compile time and could lead to an
    unexpected `ClassCastException` at runtime.
    
    If the type arguments of the parameterized type are only available at runtime, for example
    when you want to create a `List<E>` based on a `Class<E>` representing the element
    type, the method .getParameterized(Type, Type...) can be used.

    Author(s)
    - Jesse Wilson
    """

    def getRawType(self) -> type["T"]:
        """
        Returns the raw (non-generic) type for this type.
        """
        ...


    def getType(self) -> "Type":
        """
        Gets underlying `Type` instance.
        """
        ...


    def isAssignableFrom(self, cls: type[Any]) -> bool:
        """
        Check if this type is assignable from the given class object.

        Deprecated
        - this implementation may be inconsistent with javac for types with wildcards.
        """
        ...


    def isAssignableFrom(self, from: "Type") -> bool:
        """
        Check if this type is assignable from the given Type.

        Deprecated
        - this implementation may be inconsistent with javac for types with wildcards.
        """
        ...


    def isAssignableFrom(self, token: "TypeToken"[Any]) -> bool:
        """
        Check if this type is assignable from the given type token.

        Deprecated
        - this implementation may be inconsistent with javac for types with wildcards.
        """
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, o: "Object") -> bool:
        ...


    def toString(self) -> str:
        ...


    @staticmethod
    def get(type: "Type") -> "TypeToken"[Any]:
        """
        Gets type literal for the given `Type` instance.
        """
        ...


    @staticmethod
    def get(type: type["T"]) -> "TypeToken"["T"]:
        """
        Gets type literal for the given `Class` instance.
        """
        ...


    @staticmethod
    def getParameterized(rawType: "Type", *typeArguments: Tuple["Type", ...]) -> "TypeToken"[Any]:
        """
        Gets a type literal for the parameterized type represented by applying `typeArguments` to
        `rawType`. This is mainly intended for situations where the type arguments are not
        available at compile time. The following example shows how a type token for `Map<K, V>`
        can be created:
        
        ````Class<K> keyClass = ...;
        Class<V> valueClass = ...;
        TypeToken<?> mapTypeToken = TypeToken.getParameterized(Map.class, keyClass, valueClass);````
        
        As seen here the result is a `TypeToken<?>`; this method cannot provide any type-safety,
        and care must be taken to pass in the correct number of type arguments.
        
        If `rawType` is a non-generic class and no type arguments are provided, this method
        simply delegates to .get(Class) and creates a `TypeToken(Class)`.

        Raises
        - IllegalArgumentException: If `rawType` is not of type `Class`, or if the
            type arguments are invalid for the raw type
        """
        ...


    @staticmethod
    def getArray(componentType: "Type") -> "TypeToken"[Any]:
        """
        Gets type literal for the array type whose elements are all instances of `componentType`.
        """
        ...



"""
Python module generated from Java source file org.bukkit.material.Openable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class Openable:

    def isOpen(self) -> bool:
        """
        Check to see if the door is open.

        Returns
        - True if the door has swung counterclockwise around its hinge.
        """
        ...


    def setOpen(self, isOpen: bool) -> None:
        """
        Configure this door to be either open or closed;

        Arguments
        - isOpen: True to open the door.
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.weather.WeatherChangeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import World
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.weather import *
from typing import Any, Callable, Iterable, Tuple


class WeatherChangeEvent(WeatherEvent, Cancellable):
    """
    Stores data for weather changing in a world
    """

    def __init__(self, world: "World", to: bool):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def toWeatherState(self) -> bool:
        """
        Gets the state of weather that the world is being set to

        Returns
        - True if the weather is being set to raining, False otherwise
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.material.Tree

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit import TreeSpecies
from org.bukkit.block import BlockFace
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class Tree(Wood):
    """
    Represents the different types of Tree block that face a direction.

    See
    - Material.LEGACY_LOG_2

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self):
        """
        Constructs a tree block.
        """
        ...


    def __init__(self, species: "TreeSpecies"):
        """
        Constructs a tree block of the given tree species.

        Arguments
        - species: the species of the tree block
        """
        ...


    def __init__(self, species: "TreeSpecies", dir: "BlockFace"):
        """
        Constructs a tree block of the given tree species, and facing the given
        direction.

        Arguments
        - species: the species of the tree block
        - dir: the direction the tree block is facing
        """
        ...


    def __init__(self, type: "Material"):
        """
        Constructs a tree block of the given type.

        Arguments
        - type: the type of tree block
        """
        ...


    def __init__(self, type: "Material", species: "TreeSpecies"):
        """
        Constructs a tree block of the given type and tree species.

        Arguments
        - type: the type of tree block
        - species: the species of the tree block
        """
        ...


    def __init__(self, type: "Material", species: "TreeSpecies", dir: "BlockFace"):
        """
        Constructs a tree block of the given type and tree species, and facing
        the given direction.

        Arguments
        - type: the type of tree block
        - species: the species of the tree block
        - dir: the direction the tree block is facing
        """
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def getDirection(self) -> "BlockFace":
        """
        Get direction of the log

        Returns
        - one of:
        
        - BlockFace.TOP for upright (default)
        - BlockFace.NORTH (east-west)
        - BlockFace.WEST (north-south)
        - BlockFace.SELF (directionless)
        """
        ...


    def setDirection(self, dir: "BlockFace") -> None:
        """
        Set direction of the log

        Arguments
        - dir: - direction of end of log (BlockFace.SELF for no direction)
        """
        ...


    def toString(self) -> str:
        ...


    def clone(self) -> "Tree":
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.AsyncFunction

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.util.concurrent import *
from java.util.concurrent import Future
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class AsyncFunction:
    """
    Transforms a value, possibly asynchronously. For an example usage and more information, see
    Futures.transformAsync(ListenableFuture, AsyncFunction, Executor).

    Author(s)
    - Chris Povirk

    Since
    - 11.0
    """

    def apply(self, input: "I") -> "ListenableFuture"["O"]:
        """
        Returns an output `Future` to use in place of the given `input`. The output `Future` need not be Future.isDone done, making `AsyncFunction` suitable for
        asynchronous derivations.
        
        Throwing an exception from this method is equivalent to returning a failing `Future`.
        """
        ...



"""
Python module generated from Java source file com.google.common.primitives.ElementTypesAreNonnullByDefault

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.primitives import *
from javax.annotation import Nonnull
from javax.annotation.meta import TypeQualifierDefault
from typing import Any, Callable, Iterable, Tuple


class ElementTypesAreNonnullByDefault:
    """
    Marks all "top-level" types as non-null in a way that is recognized by Kotlin. Note that this
    unfortunately includes type-variable usages, so we also provide ParametricNullness to
    "undo" it as best we can.
    """





"""
Python module generated from Java source file com.google.common.collect.AbstractSortedKeySortedSetMultimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from java.util import SortedMap
from java.util import SortedSet
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class AbstractSortedKeySortedSetMultimap(AbstractSortedSetMultimap):
    """
    Basic implementation of a SortedSetMultimap with a sorted key set.
    
    This superclass allows `TreeMultimap` to override methods to return navigable set and
    map types in non-GWT only, while GWT code will inherit the SortedMap/SortedSet overrides.

    Author(s)
    - Louis Wasserman
    """

    def asMap(self) -> "SortedMap"["K", Iterable["V"]]:
        ...


    def keySet(self) -> "SortedSet"["K"]:
        ...



"""
Python module generated from Java source file org.bukkit.Axis

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class Axis(Enum):
    """
    Represents a mutually perpendicular axis in 3D Cartesian coordinates. In
    Minecraft the x, z axes lie in the horizontal plane, whilst the y axis points
    upwards.
    """

    X = 0
    """
    The x axis.
    """
    Y = 1
    """
    The y axis.
    """
    Z = 2
    """
    The z axis.
    """



from .TypeAdapterFactory import TypeAdapterFactory
from .TypeAdapter import TypeAdapter
from .ToNumberStrategy import ToNumberStrategy
from .ToNumberPolicy import ToNumberPolicy
from .Strictness import Strictness
from .ReflectionAccessFilter import ReflectionAccessFilter
from .LongSerializationPolicy import LongSerializationPolicy
from .JsonSyntaxException import JsonSyntaxException
from .JsonStreamParser import JsonStreamParser
from .JsonSerializer import JsonSerializer
from .JsonSerializationContext import JsonSerializationContext
from .JsonPrimitive import JsonPrimitive
from .JsonParser import JsonParser
from .JsonParseException import JsonParseException
from .JsonObject import JsonObject
from .JsonNull import JsonNull
from .JsonIOException import JsonIOException
from .JsonElement import JsonElement
from .JsonDeserializer import JsonDeserializer
from .JsonDeserializationContext import JsonDeserializationContext
from .JsonArray import JsonArray
from .InstanceCreator import InstanceCreator
from .GsonBuilder import GsonBuilder
from .Gson import Gson
from .FormattingStyle import FormattingStyle
from .FieldNamingStrategy import FieldNamingStrategy
from .FieldNamingPolicy import FieldNamingPolicy
from .FieldAttributes import FieldAttributes
from .ExclusionStrategy import ExclusionStrategy


"""
Python module generated from Java source file com.google.common.collect.AbstractTable

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations.concurrent import LazyInit
from com.google.j2objc.annotations import WeakOuter
from java.util import AbstractCollection
from java.util import AbstractSet
from java.util import Iterator
from java.util import Spliterator
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class AbstractTable(Table):
    """
    Skeletal, implementation-agnostic implementation of the Table interface.

    Author(s)
    - Louis Wasserman
    """

    def containsRow(self, rowKey: "Object") -> bool:
        ...


    def containsColumn(self, columnKey: "Object") -> bool:
        ...


    def rowKeySet(self) -> set["R"]:
        ...


    def columnKeySet(self) -> set["C"]:
        ...


    def containsValue(self, value: "Object") -> bool:
        ...


    def contains(self, rowKey: "Object", columnKey: "Object") -> bool:
        ...


    def get(self, rowKey: "Object", columnKey: "Object") -> "V":
        ...


    def isEmpty(self) -> bool:
        ...


    def clear(self) -> None:
        ...


    def remove(self, rowKey: "Object", columnKey: "Object") -> "V":
        ...


    def put(self, rowKey: "R", columnKey: "C", value: "V") -> "V":
        ...


    def putAll(self, table: "Table"["R", "C", "V"]) -> None:
        ...


    def cellSet(self) -> set["Cell"["R", "C", "V"]]:
        ...


    def values(self) -> Iterable["V"]:
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...


    def toString(self) -> str:
        """
        Returns the string representation `rowMap().toString()`.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableEntry

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from java.io import Serializable
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ImmutableEntry(AbstractMapEntry, Serializable):
    """
    An immutable `Map.Entry`, used both by com.google.common.collect.Maps.immutableEntry(Object, Object) and by other parts of `common.collect` as a superclass.
    """

    def getKey(self) -> "K":
        ...


    def getValue(self) -> "V":
        ...


    def setValue(self, value: "V") -> "V":
        ...



"""
Python module generated from Java source file com.google.gson.TypeAdapterFactory

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from com.google.gson.reflect import TypeToken
from typing import Any, Callable, Iterable, Tuple


class TypeAdapterFactory:
    """
    Creates type adapters for set of related types. Type adapter factories are most useful when
    several types share similar structure in their JSON form.
    
    <h2>Examples</h2>
    
    <h3>Example: Converting enums to lowercase</h3>
    
    In this example, we implement a factory that creates type adapters for all enums. The type
    adapters will write enums in lowercase, despite the fact that they're defined in `CONSTANT_CASE` in the corresponding Java model:
    
    ````public class LowercaseEnumTypeAdapterFactory implements TypeAdapterFactory {
      public <T> TypeAdapter<T> create(Gson gson, TypeToken<T> type) {
        Class<T> rawType = (Class<T>) type.getRawType();
        if (!rawType.isEnum()) {
          return null;`
    
        final Map<String, T> lowercaseToConstant = new HashMap<>();
        for (T constant : rawType.getEnumConstants()) {
          lowercaseToConstant.put(toLowercase(constant), constant);
        }
    
        return new TypeAdapter<T>() {
          public void write(JsonWriter out, T value) throws IOException {
            if (value == null) {
              out.nullValue();
            } else {
              out.value(toLowercase(value));
            }
          }
    
          public T read(JsonReader reader) throws IOException {
            if (reader.peek() == JsonToken.NULL) {
              reader.nextNull();
              return null;
            } else {
              return lowercaseToConstant.get(reader.nextString());
            }
          }
        };
      }
    
      private String toLowercase(Object o) {
        return o.toString().toLowerCase(Locale.US);
      }
    }
    }```
    
    Type adapter factories select which types they provide type adapters for. If a factory cannot
    support a given type, it must return null when that type is passed to .create. Factories
    should expect `create()` to be called on them for many types and should return null for
    most of those types. In the above example the factory returns null for calls to `create()`
    where `type` is not an enum.
    
    A factory is typically called once per type, but the returned type adapter may be used many
    times. It is most efficient to do expensive work like reflection in `create()` so that the
    type adapter's `read()` and `write()` methods can be very fast. In this example the
    mapping from lowercase name to enum value is computed eagerly.
    
    As with type adapters, factories must be *registered* with a com.google.gson.GsonBuilder for them to take effect:
    
    ````GsonBuilder builder = new GsonBuilder();
    builder.registerTypeAdapterFactory(new LowercaseEnumTypeAdapterFactory());
    ...
    Gson gson = builder.create();````
    
    If multiple factories support the same type, the factory registered earlier takes precedence.
    
    <h3>Example: Composing other type adapters</h3>
    
    In this example we implement a factory for Guava's `Multiset` collection type. The factory
    can be used to create type adapters for multisets of any element type: the type adapter for
    `Multiset<String>` is different from the type adapter for `Multiset<URL>`.
    
    The type adapter *delegates* to another type adapter for the multiset elements. It
    figures out the element type by reflecting on the multiset's type token. A `Gson` is passed
    in to `create` for just this purpose:
    
    ````public class MultisetTypeAdapterFactory implements TypeAdapterFactory {
      public <T> TypeAdapter<T> create(Gson gson, TypeToken<T> typeToken) {
        Type type = typeToken.getType();
        if (typeToken.getRawType() != Multiset.class
            || !(type instanceof ParameterizedType)) {
          return null;`
    
        Type elementType = ((ParameterizedType) type).getActualTypeArguments()[0];
        TypeAdapter<?> elementAdapter = gson.getAdapter(TypeToken.get(elementType));
        return (TypeAdapter<T>) newMultisetAdapter(elementAdapter);
      }
    
      private <E> TypeAdapter<Multiset<E>> newMultisetAdapter(
          final TypeAdapter<E> elementAdapter) {
        return new TypeAdapter<Multiset<E>>() {
          public void write(JsonWriter out, Multiset<E> value) throws IOException {
            if (value == null) {
              out.nullValue();
              return;
            }
    
            out.beginArray();
            for (Multiset.Entry<E> entry : value.entrySet()) {
              out.value(entry.getCount());
              elementAdapter.write(out, entry.getElement());
            }
            out.endArray();
          }
    
          public Multiset<E> read(JsonReader in) throws IOException {
            if (in.peek() == JsonToken.NULL) {
              in.nextNull();
              return null;
            }
    
            Multiset<E> result = LinkedHashMultiset.create();
            in.beginArray();
            while (in.hasNext()) {
              int count = in.nextInt();
              E element = elementAdapter.read(in);
              result.add(element, count);
            }
            in.endArray();
            return result;
          }
        };
      }
    }
    }```
    
    Delegating from one type adapter to another is extremely powerful; it's the foundation of how
    Gson converts Java objects and collections. Whenever possible your factory should retrieve its
    delegate type adapter in the `create()` method; this ensures potentially-expensive type
    adapter creation happens only once.

    Since
    - 2.1
    """

    def create(self, gson: "Gson", type: "TypeToken"["T"]) -> "TypeAdapter"["T"]:
        """
        Returns a type adapter for `type`, or null if this factory doesn't support `type`.
        """
        ...



"""
Python module generated from Java source file com.google.common.graph.ForwardingNetwork

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.graph import *
from java.util import Optional
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class ForwardingNetwork(AbstractNetwork):
    """
    A class to allow Network implementations to be backed by a provided delegate. This is not
    currently planned to be released as a general-purpose forwarding class.

    Author(s)
    - Joshua O'Madadhain
    """

    def nodes(self) -> set["N"]:
        ...


    def edges(self) -> set["E"]:
        ...


    def isDirected(self) -> bool:
        ...


    def allowsParallelEdges(self) -> bool:
        ...


    def allowsSelfLoops(self) -> bool:
        ...


    def nodeOrder(self) -> "ElementOrder"["N"]:
        ...


    def edgeOrder(self) -> "ElementOrder"["E"]:
        ...


    def adjacentNodes(self, node: "N") -> set["N"]:
        ...


    def predecessors(self, node: "N") -> set["N"]:
        ...


    def successors(self, node: "N") -> set["N"]:
        ...


    def incidentEdges(self, node: "N") -> set["E"]:
        ...


    def inEdges(self, node: "N") -> set["E"]:
        ...


    def outEdges(self, node: "N") -> set["E"]:
        ...


    def incidentNodes(self, edge: "E") -> "EndpointPair"["N"]:
        ...


    def adjacentEdges(self, edge: "E") -> set["E"]:
        ...


    def degree(self, node: "N") -> int:
        ...


    def inDegree(self, node: "N") -> int:
        ...


    def outDegree(self, node: "N") -> int:
        ...


    def edgesConnecting(self, nodeU: "N", nodeV: "N") -> set["E"]:
        ...


    def edgesConnecting(self, endpoints: "EndpointPair"["N"]) -> set["E"]:
        ...


    def edgeConnecting(self, nodeU: "N", nodeV: "N") -> "Optional"["E"]:
        ...


    def edgeConnecting(self, endpoints: "EndpointPair"["N"]) -> "Optional"["E"]:
        ...


    def edgeConnectingOrNull(self, nodeU: "N", nodeV: "N") -> "E":
        ...


    def edgeConnectingOrNull(self, endpoints: "EndpointPair"["N"]) -> "E":
        ...


    def hasEdgeConnecting(self, nodeU: "N", nodeV: "N") -> bool:
        ...


    def hasEdgeConnecting(self, endpoints: "EndpointPair"["N"]) -> bool:
        ...



"""
Python module generated from Java source file org.bukkit.block.banner.Pattern

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.collect import ImmutableMap
from java.util import NoSuchElementException
from org.bukkit import Bukkit
from org.bukkit import DyeColor
from org.bukkit import NamespacedKey
from org.bukkit import Registry
from org.bukkit.block.banner import *
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.configuration.serialization import SerializableAs
from typing import Any, Callable, Iterable, Tuple


class Pattern(ConfigurationSerializable):

    def __init__(self, color: "DyeColor", pattern: "PatternType"):
        """
        Creates a new pattern from the specified color and
        pattern type

        Arguments
        - color: the pattern color
        - pattern: the pattern type
        """
        ...


    def __init__(self, map: dict[str, "Object"]):
        """
        Constructor for deserialization.

        Arguments
        - map: the map to deserialize from
        """
        ...


    def serialize(self) -> dict[str, "Object"]:
        ...


    def getColor(self) -> "DyeColor":
        """
        Returns the color of the pattern

        Returns
        - the color of the pattern
        """
        ...


    def getPattern(self) -> "PatternType":
        """
        Returns the type of pattern

        Returns
        - the pattern type
        """
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...



from .DelegateDeserialization import DelegateDeserialization
from .SerializableAs import SerializableAs
from .ConfigurationSerialization import ConfigurationSerialization
from .ConfigurationSerializable import ConfigurationSerializable


"""
Python module generated from Java source file com.google.common.net.HttpHeaders

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.net import *
from typing import Any, Callable, Iterable, Tuple


class HttpHeaders:
    """
    Contains constant definitions for the HTTP header field names. See:
    
    
      - <a href="http://www.ietf.org/rfc/rfc2109.txt">RFC 2109</a>
      - <a href="http://www.ietf.org/rfc/rfc2183.txt">RFC 2183</a>
      - <a href="http://www.ietf.org/rfc/rfc2616.txt">RFC 2616</a>
      - <a href="http://www.ietf.org/rfc/rfc2965.txt">RFC 2965</a>
      - <a href="http://www.ietf.org/rfc/rfc5988.txt">RFC 5988</a>

    Author(s)
    - Kurt Alfred Kluever

    Since
    - 11.0
    """

    CACHE_CONTROL = "Cache-Control"
    """
    The HTTP `Cache-Control` header field name.
    """
    CONTENT_LENGTH = "Content-Length"
    """
    The HTTP `Content-Length` header field name.
    """
    CONTENT_TYPE = "Content-Type"
    """
    The HTTP `Content-Type` header field name.
    """
    DATE = "Date"
    """
    The HTTP `Date` header field name.
    """
    PRAGMA = "Pragma"
    """
    The HTTP `Pragma` header field name.
    """
    VIA = "Via"
    """
    The HTTP `Via` header field name.
    """
    WARNING = "Warning"
    """
    The HTTP `Warning` header field name.
    """
    ACCEPT = "Accept"
    """
    The HTTP `Accept` header field name.
    """
    ACCEPT_CHARSET = "Accept-Charset"
    """
    The HTTP `Accept-Charset` header field name.
    """
    ACCEPT_ENCODING = "Accept-Encoding"
    """
    The HTTP `Accept-Encoding` header field name.
    """
    ACCEPT_LANGUAGE = "Accept-Language"
    """
    The HTTP `Accept-Language` header field name.
    """
    ACCESS_CONTROL_REQUEST_HEADERS = "Access-Control-Request-Headers"
    """
    The HTTP `Access-Control-Request-Headers` header field name.
    """
    ACCESS_CONTROL_REQUEST_METHOD = "Access-Control-Request-Method"
    """
    The HTTP `Access-Control-Request-Method` header field name.
    """
    AUTHORIZATION = "Authorization"
    """
    The HTTP `Authorization` header field name.
    """
    CONNECTION = "Connection"
    """
    The HTTP `Connection` header field name.
    """
    COOKIE = "Cookie"
    """
    The HTTP `Cookie` header field name.
    """
    CROSS_ORIGIN_RESOURCE_POLICY = "Cross-Origin-Resource-Policy"
    """
    The HTTP <a href="https://fetch.spec.whatwg.org/#cross-origin-resource-policy-header">`Cross-Origin-Resource-Policy`</a> header field name.

    Since
    - 28.0
    """
    EARLY_DATA = "Early-Data"
    """
    The HTTP <a href="https://tools.ietf.org/html/rfc8470">`Early-Data`</a> header field
    name.

    Since
    - 27.0
    """
    EXPECT = "Expect"
    """
    The HTTP `Expect` header field name.
    """
    FROM = "From"
    """
    The HTTP `From` header field name.
    """
    FORWARDED = "Forwarded"
    """
    The HTTP <a href="https://tools.ietf.org/html/rfc7239">`Forwarded`</a> header field name.

    Since
    - 20.0
    """
    FOLLOW_ONLY_WHEN_PRERENDER_SHOWN = "Follow-Only-When-Prerender-Shown"
    """
    The HTTP `Follow-Only-When-Prerender-Shown` header field name.

    Since
    - 17.0
    """
    HOST = "Host"
    """
    The HTTP `Host` header field name.
    """
    HTTP2_SETTINGS = "HTTP2-Settings"
    """
    The HTTP <a href="https://tools.ietf.org/html/rfc7540#section-3.2.1">`HTTP2-Settings`
    </a> header field name.

    Since
    - 24.0
    """
    IF_MATCH = "If-Match"
    """
    The HTTP `If-Match` header field name.
    """
    IF_MODIFIED_SINCE = "If-Modified-Since"
    """
    The HTTP `If-Modified-Since` header field name.
    """
    IF_NONE_MATCH = "If-None-Match"
    """
    The HTTP `If-None-Match` header field name.
    """
    IF_RANGE = "If-Range"
    """
    The HTTP `If-Range` header field name.
    """
    IF_UNMODIFIED_SINCE = "If-Unmodified-Since"
    """
    The HTTP `If-Unmodified-Since` header field name.
    """
    LAST_EVENT_ID = "Last-Event-ID"
    """
    The HTTP `Last-Event-ID` header field name.
    """
    MAX_FORWARDS = "Max-Forwards"
    """
    The HTTP `Max-Forwards` header field name.
    """
    ORIGIN = "Origin"
    """
    The HTTP `Origin` header field name.
    """
    ORIGIN_ISOLATION = "Origin-Isolation"
    """
    The HTTP <a href="https://github.com/WICG/origin-isolation">`Origin-Isolation`</a> header
    field name.

    Since
    - 30.1
    """
    PROXY_AUTHORIZATION = "Proxy-Authorization"
    """
    The HTTP `Proxy-Authorization` header field name.
    """
    RANGE = "Range"
    """
    The HTTP `Range` header field name.
    """
    REFERER = "Referer"
    """
    The HTTP `Referer` header field name.
    """
    REFERRER_POLICY = "Referrer-Policy"
    """
    The HTTP <a href="https://www.w3.org/TR/referrer-policy/">`Referrer-Policy`</a> header
    field name.

    Since
    - 23.4
    """
    SERVICE_WORKER = "Service-Worker"
    """
    The HTTP <a href="https://www.w3.org/TR/service-workers/#update-algorithm">`Service-Worker`</a> header field name.

    Since
    - 20.0
    """
    TE = "TE"
    """
    The HTTP `TE` header field name.
    """
    UPGRADE = "Upgrade"
    """
    The HTTP `Upgrade` header field name.
    """
    UPGRADE_INSECURE_REQUESTS = "Upgrade-Insecure-Requests"
    """
    The HTTP <a href="https://w3c.github.io/webappsec-upgrade-insecure-requests/#preference">`Upgrade-Insecure-Requests`</a> header field name.

    Since
    - 28.1
    """
    USER_AGENT = "User-Agent"
    """
    The HTTP `User-Agent` header field name.
    """
    ACCEPT_RANGES = "Accept-Ranges"
    """
    The HTTP `Accept-Ranges` header field name.
    """
    ACCESS_CONTROL_ALLOW_HEADERS = "Access-Control-Allow-Headers"
    """
    The HTTP `Access-Control-Allow-Headers` header field name.
    """
    ACCESS_CONTROL_ALLOW_METHODS = "Access-Control-Allow-Methods"
    """
    The HTTP `Access-Control-Allow-Methods` header field name.
    """
    ACCESS_CONTROL_ALLOW_ORIGIN = "Access-Control-Allow-Origin"
    """
    The HTTP `Access-Control-Allow-Origin` header field name.
    """
    ACCESS_CONTROL_ALLOW_PRIVATE_NETWORK = "Access-Control-Allow-Private-Network"
    """
    The HTTP <a href="https://wicg.github.io/private-network-access/#headers">`Access-Control-Allow-Private-Network`</a> header field name.

    Since
    - 31.1
    """
    ACCESS_CONTROL_ALLOW_CREDENTIALS = "Access-Control-Allow-Credentials"
    """
    The HTTP `Access-Control-Allow-Credentials` header field name.
    """
    ACCESS_CONTROL_EXPOSE_HEADERS = "Access-Control-Expose-Headers"
    """
    The HTTP `Access-Control-Expose-Headers` header field name.
    """
    ACCESS_CONTROL_MAX_AGE = "Access-Control-Max-Age"
    """
    The HTTP `Access-Control-Max-Age` header field name.
    """
    AGE = "Age"
    """
    The HTTP `Age` header field name.
    """
    ALLOW = "Allow"
    """
    The HTTP `Allow` header field name.
    """
    CONTENT_DISPOSITION = "Content-Disposition"
    """
    The HTTP `Content-Disposition` header field name.
    """
    CONTENT_ENCODING = "Content-Encoding"
    """
    The HTTP `Content-Encoding` header field name.
    """
    CONTENT_LANGUAGE = "Content-Language"
    """
    The HTTP `Content-Language` header field name.
    """
    CONTENT_LOCATION = "Content-Location"
    """
    The HTTP `Content-Location` header field name.
    """
    CONTENT_MD5 = "Content-MD5"
    """
    The HTTP `Content-MD5` header field name.
    """
    CONTENT_RANGE = "Content-Range"
    """
    The HTTP `Content-Range` header field name.
    """
    CONTENT_SECURITY_POLICY = "Content-Security-Policy"
    """
    The HTTP <a href="http://w3.org/TR/CSP/#content-security-policy-header-field">`Content-Security-Policy`</a> header field name.

    Since
    - 15.0
    """
    CONTENT_SECURITY_POLICY_REPORT_ONLY = "Content-Security-Policy-Report-Only"
    """
    The HTTP <a href="http://w3.org/TR/CSP/#content-security-policy-report-only-header-field">
    `Content-Security-Policy-Report-Only`</a> header field name.

    Since
    - 15.0
    """
    X_CONTENT_SECURITY_POLICY = "X-Content-Security-Policy"
    """
    The HTTP nonstandard `X-Content-Security-Policy` header field name. It was introduced in
    <a href="https://www.w3.org/TR/2011/WD-CSP-20111129/">CSP v.1</a> and used by the Firefox until
    version 23 and the Internet Explorer version 10. Please, use .CONTENT_SECURITY_POLICY
    to pass the CSP.

    Since
    - 20.0
    """
    X_CONTENT_SECURITY_POLICY_REPORT_ONLY = "X-Content-Security-Policy-Report-Only"
    """
    The HTTP nonstandard `X-Content-Security-Policy-Report-Only` header field name. It was
    introduced in <a href="https://www.w3.org/TR/2011/WD-CSP-20111129/">CSP v.1</a> and used by the
    Firefox until version 23 and the Internet Explorer version 10. Please, use .CONTENT_SECURITY_POLICY_REPORT_ONLY to pass the CSP.

    Since
    - 20.0
    """
    X_WEBKIT_CSP = "X-WebKit-CSP"
    """
    The HTTP nonstandard `X-WebKit-CSP` header field name. It was introduced in <a
    href="https://www.w3.org/TR/2011/WD-CSP-20111129/">CSP v.1</a> and used by the Chrome until
    version 25. Please, use .CONTENT_SECURITY_POLICY to pass the CSP.

    Since
    - 20.0
    """
    X_WEBKIT_CSP_REPORT_ONLY = "X-WebKit-CSP-Report-Only"
    """
    The HTTP nonstandard `X-WebKit-CSP-Report-Only` header field name. It was introduced in
    <a href="https://www.w3.org/TR/2011/WD-CSP-20111129/">CSP v.1</a> and used by the Chrome until
    version 25. Please, use .CONTENT_SECURITY_POLICY_REPORT_ONLY to pass the CSP.

    Since
    - 20.0
    """
    CROSS_ORIGIN_EMBEDDER_POLICY = "Cross-Origin-Embedder-Policy"
    """
    The HTTP <a href="https://wicg.github.io/cross-origin-embedder-policy/#COEP">`Cross-Origin-Embedder-Policy`</a> header field name.

    Since
    - 30.0
    """
    CROSS_ORIGIN_EMBEDDER_POLICY_REPORT_ONLY = "Cross-Origin-Embedder-Policy-Report-Only"
    """
    The HTTP <a href="https://wicg.github.io/cross-origin-embedder-policy/#COEP-RO">`Cross-Origin-Embedder-Policy-Report-Only`</a> header field name.

    Since
    - 30.0
    """
    CROSS_ORIGIN_OPENER_POLICY = "Cross-Origin-Opener-Policy"
    """
    The HTTP Cross-Origin-Opener-Policy header field name.

    Since
    - 28.2
    """
    ETAG = "ETag"
    """
    The HTTP `ETag` header field name.
    """
    EXPIRES = "Expires"
    """
    The HTTP `Expires` header field name.
    """
    LAST_MODIFIED = "Last-Modified"
    """
    The HTTP `Last-Modified` header field name.
    """
    LINK = "Link"
    """
    The HTTP `Link` header field name.
    """
    LOCATION = "Location"
    """
    The HTTP `Location` header field name.
    """
    KEEP_ALIVE = "Keep-Alive"
    """
    The HTTP `Keep-Alive` header field name.

    Since
    - 31.0
    """
    NO_VARY_SEARCH = "No-Vary-Search"
    """
    The HTTP <a href="https://github.com/WICG/nav-speculation/blob/main/no-vary-search.md">`No-Vary-Seearch`</a> header field name.

    Since
    - 32.0.0
    """
    ORIGIN_TRIAL = "Origin-Trial"
    """
    The HTTP <a href="https://googlechrome.github.io/OriginTrials/#header">`Origin-Trial`</a>
    header field name.

    Since
    - 27.1
    """
    P3P = "P3P"
    """
    The HTTP `P3P` header field name. Limited browser support.
    """
    PROXY_AUTHENTICATE = "Proxy-Authenticate"
    """
    The HTTP `Proxy-Authenticate` header field name.
    """
    REFRESH = "Refresh"
    """
    The HTTP `Refresh` header field name. Non-standard header supported by most browsers.
    """
    REPORT_TO = "Report-To"
    """
    The HTTP <a href="https://www.w3.org/TR/reporting/">`Report-To`</a> header field name.

    Since
    - 27.1
    """
    RETRY_AFTER = "Retry-After"
    """
    The HTTP `Retry-After` header field name.
    """
    SERVER = "Server"
    """
    The HTTP `Server` header field name.
    """
    SERVER_TIMING = "Server-Timing"
    """
    The HTTP <a href="https://www.w3.org/TR/server-timing/">`Server-Timing`</a> header field
    name.

    Since
    - 23.6
    """
    SERVICE_WORKER_ALLOWED = "Service-Worker-Allowed"
    """
    The HTTP <a href="https://www.w3.org/TR/service-workers/#update-algorithm">`Service-Worker-Allowed`</a> header field name.

    Since
    - 20.0
    """
    SET_COOKIE = "Set-Cookie"
    """
    The HTTP `Set-Cookie` header field name.
    """
    SET_COOKIE2 = "Set-Cookie2"
    """
    The HTTP `Set-Cookie2` header field name.
    """
    SOURCE_MAP = "SourceMap"
    """
    The HTTP <a href="https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/SourceMap">`SourceMap`</a> header field name.

    Since
    - 27.1
    """
    SUPPORTS_LOADING_MODE = "Supports-Loading-Mode"
    """
    The HTTP <a href="https://github.com/WICG/nav-speculation/blob/main/opt-in.md">`Supports-Loading-Mode`</a> header field name. This can be used to specify, for example, <a
    href="https://developer.chrome.com/docs/privacy-sandbox/fenced-frame/#server-opt-in">fenced
    frames</a>.

    Since
    - 32.0.0
    """
    STRICT_TRANSPORT_SECURITY = "Strict-Transport-Security"
    """
    The HTTP <a href="http://tools.ietf.org/html/rfc6797#section-6.1">`Strict-Transport-Security`</a> header field name.

    Since
    - 15.0
    """
    TIMING_ALLOW_ORIGIN = "Timing-Allow-Origin"
    """
    The HTTP <a href="http://www.w3.org/TR/resource-timing/#cross-origin-resources">`Timing-Allow-Origin`</a> header field name.

    Since
    - 15.0
    """
    TRAILER = "Trailer"
    """
    The HTTP `Trailer` header field name.
    """
    TRANSFER_ENCODING = "Transfer-Encoding"
    """
    The HTTP `Transfer-Encoding` header field name.
    """
    VARY = "Vary"
    """
    The HTTP `Vary` header field name.
    """
    WWW_AUTHENTICATE = "WWW-Authenticate"
    """
    The HTTP `WWW-Authenticate` header field name.
    """
    DNT = "DNT"
    """
    The HTTP `DNT` header field name.
    """
    X_CONTENT_TYPE_OPTIONS = "X-Content-Type-Options"
    """
    The HTTP `X-Content-Type-Options` header field name.
    """
    X_DEVICE_IP = "X-Device-IP"
    """
    The HTTP <a
    href="https://iabtechlab.com/wp-content/uploads/2019/06/VAST_4.2_final_june26.pdf">`X-Device-IP`</a> header field name. Header used for VAST requests to provide the IP address of
    the device on whose behalf the request is being made.

    Since
    - 31.0
    """
    X_DEVICE_REFERER = "X-Device-Referer"
    """
    The HTTP <a
    href="https://iabtechlab.com/wp-content/uploads/2019/06/VAST_4.2_final_june26.pdf">`X-Device-Referer`</a> header field name. Header used for VAST requests to provide the .REFERER header value that the on-behalf-of client would have used when making a request
    itself.

    Since
    - 31.0
    """
    X_DEVICE_ACCEPT_LANGUAGE = "X-Device-Accept-Language"
    """
    The HTTP <a
    href="https://iabtechlab.com/wp-content/uploads/2019/06/VAST_4.2_final_june26.pdf">`X-Device-Accept-Language`</a> header field name. Header used for VAST requests to provide the
    .ACCEPT_LANGUAGE header value that the on-behalf-of client would have used when making
    a request itself.

    Since
    - 31.0
    """
    X_DEVICE_REQUESTED_WITH = "X-Device-Requested-With"
    """
    The HTTP <a
    href="https://iabtechlab.com/wp-content/uploads/2019/06/VAST_4.2_final_june26.pdf">`X-Device-Requested-With`</a> header field name. Header used for VAST requests to provide the
    .X_REQUESTED_WITH header value that the on-behalf-of client would have used when making
    a request itself.

    Since
    - 31.0
    """
    X_DO_NOT_TRACK = "X-Do-Not-Track"
    """
    The HTTP `X-Do-Not-Track` header field name.
    """
    X_FORWARDED_FOR = "X-Forwarded-For"
    """
    The HTTP `X-Forwarded-For` header field name (superseded by `Forwarded`).
    """
    X_FORWARDED_PROTO = "X-Forwarded-Proto"
    """
    The HTTP `X-Forwarded-Proto` header field name.
    """
    X_FORWARDED_HOST = "X-Forwarded-Host"
    """
    The HTTP <a
    href="https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Forwarded-Host">`X-Forwarded-Host`</a> header field name.

    Since
    - 20.0
    """
    X_FORWARDED_PORT = "X-Forwarded-Port"
    """
    The HTTP <a
    href="https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/x-forwarded-headers.html#x-forwarded-port">`X-Forwarded-Port`</a> header field name.

    Since
    - 20.0
    """
    X_FRAME_OPTIONS = "X-Frame-Options"
    """
    The HTTP `X-Frame-Options` header field name.
    """
    X_POWERED_BY = "X-Powered-By"
    """
    The HTTP `X-Powered-By` header field name.
    """
    PUBLIC_KEY_PINS = "Public-Key-Pins"
    """
    The HTTP <a href="http://tools.ietf.org/html/draft-evans-palmer-key-pinning">`Public-Key-Pins`</a> header field name.

    Since
    - 15.0
    """
    PUBLIC_KEY_PINS_REPORT_ONLY = "Public-Key-Pins-Report-Only"
    """
    The HTTP <a href="http://tools.ietf.org/html/draft-evans-palmer-key-pinning">`Public-Key-Pins-Report-Only`</a> header field name.

    Since
    - 15.0
    """
    X_REQUEST_ID = "X-Request-ID"
    """
    The HTTP `X-Request-ID` header field name.

    Since
    - 30.1
    """
    X_REQUESTED_WITH = "X-Requested-With"
    """
    The HTTP `X-Requested-With` header field name.
    """
    X_USER_IP = "X-User-IP"
    """
    The HTTP `X-User-IP` header field name.
    """
    X_DOWNLOAD_OPTIONS = "X-Download-Options"
    """
    The HTTP <a
    href="https://learn.microsoft.com/en-us/archive/blogs/ieinternals/internet-explorer-and-custom-http-headers#:~:text=X%2DDownload%2DOptions">`X-Download-Options`</a> header field name.
    
    When the new X-Download-Options header is present with the value `noopen`, the user is
    prevented from opening a file download directly; instead, they must first save the file
    locally.

    Since
    - 24.1
    """
    X_XSS_PROTECTION = "X-XSS-Protection"
    """
    The HTTP `X-XSS-Protection` header field name.
    """
    X_DNS_PREFETCH_CONTROL = "X-DNS-Prefetch-Control"
    """
    The HTTP <a
    href="https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-DNS-Prefetch-Control">`X-DNS-Prefetch-Control`</a> header controls DNS prefetch behavior. Value can be "on" or "off".
    By default, DNS prefetching is "on" for HTTP pages and "off" for HTTPS pages.
    """
    PING_FROM = "Ping-From"
    """
    The HTTP <a href="http://html.spec.whatwg.org/multipage/semantics.html#hyperlink-auditing">
    `Ping-From`</a> header field name.

    Since
    - 19.0
    """
    PING_TO = "Ping-To"
    """
    The HTTP <a href="http://html.spec.whatwg.org/multipage/semantics.html#hyperlink-auditing">
    `Ping-To`</a> header field name.

    Since
    - 19.0
    """
    PURPOSE = "Purpose"
    """
    The HTTP <a
    href="https://developer.mozilla.org/en-US/docs/Web/HTTP/Link_prefetching_FAQ#As_a_server_admin.2C_can_I_distinguish_prefetch_requests_from_normal_requests.3F">`Purpose`</a> header field name.

    Since
    - 28.0
    """
    X_PURPOSE = "X-Purpose"
    """
    The HTTP <a
    href="https://developer.mozilla.org/en-US/docs/Web/HTTP/Link_prefetching_FAQ#As_a_server_admin.2C_can_I_distinguish_prefetch_requests_from_normal_requests.3F">`X-Purpose`</a> header field name.

    Since
    - 28.0
    """
    X_MOZ = "X-Moz"
    """
    The HTTP <a
    href="https://developer.mozilla.org/en-US/docs/Web/HTTP/Link_prefetching_FAQ#As_a_server_admin.2C_can_I_distinguish_prefetch_requests_from_normal_requests.3F">`X-Moz`</a> header field name.

    Since
    - 28.0
    """
    DEVICE_MEMORY = "Device-Memory"
    """
    The HTTP <a
    href="https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Device-Memory">`Device-Memory`</a> header field name.

    Since
    - 31.0
    """
    DOWNLINK = "Downlink"
    """
    The HTTP <a href="https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Downlink">`Downlink`</a> header field name.

    Since
    - 31.0
    """
    ECT = "ECT"
    """
    The HTTP <a href="https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/ECT">`ECT`</a> header field name.

    Since
    - 31.0
    """
    RTT = "RTT"
    """
    The HTTP <a href="https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/RTT">`RTT`</a> header field name.

    Since
    - 31.0
    """
    SAVE_DATA = "Save-Data"
    """
    The HTTP <a href="https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Save-Data">`Save-Data`</a> header field name.

    Since
    - 31.0
    """
    VIEWPORT_WIDTH = "Viewport-Width"
    """
    The HTTP <a
    href="https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Viewport-Width">`Viewport-Width`</a> header field name.

    Since
    - 31.0
    """
    WIDTH = "Width"
    """
    The HTTP <a href="https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Width">`Width`</a> header field name.

    Since
    - 31.0
    """
    PERMISSIONS_POLICY = "Permissions-Policy"
    """
    The HTTP <a href="https://www.w3.org/TR/permissions-policy-1/">`Permissions-Policy`</a>
    header field name.

    Since
    - 31.0
    """
    PERMISSIONS_POLICY_REPORT_ONLY = "Permissions-Policy-Report-Only"
    """
    The HTTP <a
    href="https://w3c.github.io/webappsec-permissions-policy/#permissions-policy-report-only-http-header-field">`Permissions-Policy-Report-Only`</a> header field name.

    Since
    - 33.2.0
    """
    SEC_CH_PREFERS_COLOR_SCHEME = "Sec-CH-Prefers-Color-Scheme"
    """
    The HTTP <a
    href="https://wicg.github.io/user-preference-media-features-headers/#sec-ch-prefers-color-scheme">`Sec-CH-Prefers-Color-Scheme`</a> header field name.
    
    This header is experimental.

    Since
    - 31.0
    """
    ACCEPT_CH = "Accept-CH"
    """
    The HTTP <a
    href="https://www.rfc-editor.org/rfc/rfc8942#name-the-accept-ch-response-head">`Accept-CH`</a> header field name.

    Since
    - 31.0
    """
    CRITICAL_CH = "Critical-CH"
    """
    The HTTP <a
    href="https://datatracker.ietf.org/doc/html/draft-davidben-http-client-hint-reliability-03.txt#section-3">`Critical-CH`</a> header field name.

    Since
    - 31.0
    """
    SEC_CH_UA = "Sec-CH-UA"
    """
    The HTTP <a href="https://wicg.github.io/ua-client-hints/#sec-ch-ua">`Sec-CH-UA`</a>
    header field name.

    Since
    - 30.0
    """
    SEC_CH_UA_ARCH = "Sec-CH-UA-Arch"
    """
    The HTTP <a href="https://wicg.github.io/ua-client-hints/#sec-ch-ua-arch">`Sec-CH-UA-Arch`</a> header field name.

    Since
    - 30.0
    """
    SEC_CH_UA_MODEL = "Sec-CH-UA-Model"
    """
    The HTTP <a href="https://wicg.github.io/ua-client-hints/#sec-ch-ua-model">`Sec-CH-UA-Model`</a> header field name.

    Since
    - 30.0
    """
    SEC_CH_UA_PLATFORM = "Sec-CH-UA-Platform"
    """
    The HTTP <a href="https://wicg.github.io/ua-client-hints/#sec-ch-ua-platform">`Sec-CH-UA-Platform`</a> header field name.

    Since
    - 30.0
    """
    SEC_CH_UA_PLATFORM_VERSION = "Sec-CH-UA-Platform-Version"
    """
    The HTTP <a href="https://wicg.github.io/ua-client-hints/#sec-ch-ua-platform-version">`Sec-CH-UA-Platform-Version`</a> header field name.

    Since
    - 30.0
    """
    SEC_CH_UA_FULL_VERSION = "Sec-CH-UA-Full-Version"
    """
    The HTTP <a href="https://wicg.github.io/ua-client-hints/#sec-ch-ua-full-version">`Sec-CH-UA-Full-Version`</a> header field name.

    Since
    - 30.0

    Deprecated
    - Prefer SEC_CH_UA_FULL_VERSION_LIST.
    """
    SEC_CH_UA_FULL_VERSION_LIST = "Sec-CH-UA-Full-Version-List"
    """
    The HTTP <a href="https://wicg.github.io/ua-client-hints/#sec-ch-ua-full-version-list">`Sec-CH-UA-Full-Version`</a> header field name.

    Since
    - 31.1
    """
    SEC_CH_UA_MOBILE = "Sec-CH-UA-Mobile"
    """
    The HTTP <a href="https://wicg.github.io/ua-client-hints/#sec-ch-ua-mobile">`Sec-CH-UA-Mobile`</a> header field name.

    Since
    - 30.0
    """
    SEC_CH_UA_WOW64 = "Sec-CH-UA-WoW64"
    """
    The HTTP <a href="https://wicg.github.io/ua-client-hints/#sec-ch-ua-wow64">`Sec-CH-UA-WoW64`</a> header field name.

    Since
    - 32.0.0
    """
    SEC_CH_UA_BITNESS = "Sec-CH-UA-Bitness"
    """
    The HTTP <a href="https://wicg.github.io/ua-client-hints/#sec-ch-ua-bitness">`Sec-CH-UA-Bitness`</a> header field name.

    Since
    - 31.0
    """
    SEC_CH_UA_FORM_FACTOR = "Sec-CH-UA-Form-Factor"
    """
    The HTTP <a href="https://wicg.github.io/ua-client-hints/#sec-ch-ua-form-factor">`Sec-CH-UA-Form-Factor`</a> header field name.

    Since
    - 32.0.0

    Deprecated
    - Prefer SEC_CH_UA_FORM_FACTORS.
    """
    SEC_CH_UA_FORM_FACTORS = "Sec-CH-UA-Form-Factors"
    """
    The HTTP <a href="https://wicg.github.io/ua-client-hints/#sec-ch-ua-form-factors">`Sec-CH-UA-Form-Factors`</a> header field name.

    Since
    - 33.3.0
    """
    SEC_CH_VIEWPORT_WIDTH = "Sec-CH-Viewport-Width"
    """
    The HTTP <a
    href="https://wicg.github.io/responsive-image-client-hints/#sec-ch-viewport-width">`Sec-CH-Viewport-Width`</a> header field name.

    Since
    - 32.0.0
    """
    SEC_CH_VIEWPORT_HEIGHT = "Sec-CH-Viewport-Height"
    """
    The HTTP <a
    href="https://wicg.github.io/responsive-image-client-hints/#sec-ch-viewport-height">`Sec-CH-Viewport-Height`</a> header field name.

    Since
    - 32.0.0
    """
    SEC_CH_DPR = "Sec-CH-DPR"
    """
    The HTTP <a href="https://wicg.github.io/responsive-image-client-hints/#sec-ch-dpr">`Sec-CH-DPR`</a> header field name.

    Since
    - 32.0.0
    """
    SEC_FETCH_DEST = "Sec-Fetch-Dest"
    """
    The HTTP <a href="https://w3c.github.io/webappsec-fetch-metadata/">`Sec-Fetch-Dest`</a>
    header field name.

    Since
    - 27.1
    """
    SEC_FETCH_MODE = "Sec-Fetch-Mode"
    """
    The HTTP <a href="https://w3c.github.io/webappsec-fetch-metadata/">`Sec-Fetch-Mode`</a>
    header field name.

    Since
    - 27.1
    """
    SEC_FETCH_SITE = "Sec-Fetch-Site"
    """
    The HTTP <a href="https://w3c.github.io/webappsec-fetch-metadata/">`Sec-Fetch-Site`</a>
    header field name.

    Since
    - 27.1
    """
    SEC_FETCH_USER = "Sec-Fetch-User"
    """
    The HTTP <a href="https://w3c.github.io/webappsec-fetch-metadata/">`Sec-Fetch-User`</a>
    header field name.

    Since
    - 27.1
    """
    SEC_METADATA = "Sec-Metadata"
    """
    The HTTP <a href="https://w3c.github.io/webappsec-fetch-metadata/">`Sec-Metadata`</a>
    header field name.

    Since
    - 26.0
    """
    SEC_TOKEN_BINDING = "Sec-Token-Binding"
    """
    The HTTP <a href="https://tools.ietf.org/html/draft-ietf-tokbind-https">`Sec-Token-Binding`</a> header field name.

    Since
    - 25.1
    """
    SEC_PROVIDED_TOKEN_BINDING_ID = "Sec-Provided-Token-Binding-ID"
    """
    The HTTP <a href="https://tools.ietf.org/html/draft-ietf-tokbind-ttrp">`Sec-Provided-Token-Binding-ID`</a> header field name.

    Since
    - 25.1
    """
    SEC_REFERRED_TOKEN_BINDING_ID = "Sec-Referred-Token-Binding-ID"
    """
    The HTTP <a href="https://tools.ietf.org/html/draft-ietf-tokbind-ttrp">`Sec-Referred-Token-Binding-ID`</a> header field name.

    Since
    - 25.1
    """
    SEC_WEBSOCKET_ACCEPT = "Sec-WebSocket-Accept"
    """
    The HTTP <a href="https://tools.ietf.org/html/rfc6455">`Sec-WebSocket-Accept`</a> header
    field name.

    Since
    - 28.0
    """
    SEC_WEBSOCKET_EXTENSIONS = "Sec-WebSocket-Extensions"
    """
    The HTTP <a href="https://tools.ietf.org/html/rfc6455">`Sec-WebSocket-Extensions`</a>
    header field name.

    Since
    - 28.0
    """
    SEC_WEBSOCKET_KEY = "Sec-WebSocket-Key"
    """
    The HTTP <a href="https://tools.ietf.org/html/rfc6455">`Sec-WebSocket-Key`</a> header
    field name.

    Since
    - 28.0
    """
    SEC_WEBSOCKET_PROTOCOL = "Sec-WebSocket-Protocol"
    """
    The HTTP <a href="https://tools.ietf.org/html/rfc6455">`Sec-WebSocket-Protocol`</a>
    header field name.

    Since
    - 28.0
    """
    SEC_WEBSOCKET_VERSION = "Sec-WebSocket-Version"
    """
    The HTTP <a href="https://tools.ietf.org/html/rfc6455">`Sec-WebSocket-Version`</a> header
    field name.

    Since
    - 28.0
    """
    SEC_BROWSING_TOPICS = "Sec-Browsing-Topics"
    """
    The HTTP <a href="https://patcg-individual-drafts.github.io/topics/">`Sec-Browsing-Topics`</a> header field name.

    Since
    - 32.0.0
    """
    OBSERVE_BROWSING_TOPICS = "Observe-Browsing-Topics"
    """
    The HTTP <a href="https://patcg-individual-drafts.github.io/topics/">`Observe-Browsing-Topics`</a> header field name.

    Since
    - 32.0.0
    """
    SEC_AD_AUCTION_FETCH = "Sec-Ad-Auction-Fetch"
    """
    The HTTP <a
    href="https://wicg.github.io/turtledove/#handling-direct-from-seller-signals">`Sec-Ad-Auction-Fetch`</a> header field name.

    Since
    - 33.0.0
    """
    SEC_GPC = "Sec-GPC"
    """
    The HTTP <a
    href="https://privacycg.github.io/gpc-spec/#the-sec-gpc-header-field-for-http-requests">`Sec-GPC`</a> header field name.

    Since
    - 33.2.0
    """
    AD_AUCTION_SIGNALS = "Ad-Auction-Signals"
    """
    The HTTP <a
    href="https://wicg.github.io/turtledove/#handling-direct-from-seller-signals">`Ad-Auction-Signals`</a> header field name.

    Since
    - 33.0.0
    """
    AD_AUCTION_ALLOWED = "Ad-Auction-Allowed"
    """
    The HTTP <a href="https://wicg.github.io/turtledove/#http-headerdef-ad-auction-allowed">`Ad-Auction-Allowed`</a> header field name.

    Since
    - 33.2.0
    """
    CDN_LOOP = "CDN-Loop"
    """
    The HTTP <a href="https://tools.ietf.org/html/rfc8586">`CDN-Loop`</a> header field name.

    Since
    - 28.0
    """


    class ReferrerPolicyValues:
        """
        Values for the <a href="https://www.w3.org/TR/referrer-policy/">`Referrer-Policy`</a>
        header.

        Since
        - 23.4
        """

        NO_REFERRER = "no-referrer"
        NO_REFFERER_WHEN_DOWNGRADE = "no-referrer-when-downgrade"
        SAME_ORIGIN = "same-origin"
        ORIGIN = "origin"
        STRICT_ORIGIN = "strict-origin"
        ORIGIN_WHEN_CROSS_ORIGIN = "origin-when-cross-origin"
        STRICT_ORIGIN_WHEN_CROSS_ORIGIN = "strict-origin-when-cross-origin"
        UNSAFE_URL = "unsafe-url"



"""
Python module generated from Java source file java.util.EventObject

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from typing import Any, Callable, Iterable, Tuple


class EventObject(Serializable):

    def __init__(self, source: "Object"):
        """
        Constructs a prototypical Event.

        Arguments
        - source: the object on which the Event initially occurred

        Raises
        - IllegalArgumentException: if source is null
        """
        ...


    def getSource(self) -> "Object":
        """
        The object on which the Event initially occurred.

        Returns
        - the object on which the Event initially occurred
        """
        ...


    def toString(self) -> str:
        """
        Returns a String representation of this EventObject.

        Returns
        - a String representation of this EventObject
        """
        ...



"""
Python module generated from Java source file com.google.gson.JsonObject

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.gson import *
from com.google.gson.internal import LinkedTreeMap
from typing import Any, Callable, Iterable, Tuple


class JsonObject(JsonElement):
    """
    A class representing an object type in JSON. An object consists of name-value pairs where names
    are strings, and values are any other type of JsonElement. This allows for a creating a
    tree of JsonElements. The member elements of this object are maintained in order they were added.
    This class does not support `null` values. If `null` is provided as value argument to
    any of the methods, it is converted to a JsonNull.
    
    `JsonObject` does not implement the Map interface, but a `Map` view of it
    can be obtained with .asMap().
    
    See the JsonElement documentation for details on how to convert `JsonObject` and
    generally any `JsonElement` from and to JSON.

    Author(s)
    - Joel Leitch
    """

    def __init__(self):
        """
        Creates an empty JsonObject.
        """
        ...


    def deepCopy(self) -> "JsonObject":
        """
        Creates a deep copy of this element and all its children.

        Since
        - 2.8.2
        """
        ...


    def add(self, property: str, value: "JsonElement") -> None:
        """
        Adds a member, which is a name-value pair, to self. The name must be a String, but the value
        can be an arbitrary JsonElement, thereby allowing you to build a full tree of
        JsonElements rooted at this node.

        Arguments
        - property: name of the member.
        - value: the member object.
        """
        ...


    def remove(self, property: str) -> "JsonElement":
        """
        Removes the `property` from this object.

        Arguments
        - property: name of the member that should be removed.

        Returns
        - the JsonElement object that is being removed, or `null` if no member with
            this name exists.

        Since
        - 1.3
        """
        ...


    def addProperty(self, property: str, value: str) -> None:
        """
        Convenience method to add a string member. The specified value is converted to a JsonPrimitive of String.

        Arguments
        - property: name of the member.
        - value: the string value associated with the member.
        """
        ...


    def addProperty(self, property: str, value: "Number") -> None:
        """
        Convenience method to add a number member. The specified value is converted to a JsonPrimitive of Number.

        Arguments
        - property: name of the member.
        - value: the number value associated with the member.
        """
        ...


    def addProperty(self, property: str, value: "Boolean") -> None:
        """
        Convenience method to add a boolean member. The specified value is converted to a JsonPrimitive of Boolean.

        Arguments
        - property: name of the member.
        - value: the boolean value associated with the member.
        """
        ...


    def addProperty(self, property: str, value: "Character") -> None:
        """
        Convenience method to add a char member. The specified value is converted to a JsonPrimitive of Character.

        Arguments
        - property: name of the member.
        - value: the char value associated with the member.
        """
        ...


    def entrySet(self) -> set["Map.Entry"[str, "JsonElement"]]:
        """
        Returns a set of members of this object. The set is ordered, and the order is in which the
        elements were added.

        Returns
        - a set of members of this object.
        """
        ...


    def keySet(self) -> set[str]:
        """
        Returns a set of members key values.

        Returns
        - a set of member keys as Strings

        Since
        - 2.8.1
        """
        ...


    def size(self) -> int:
        """
        Returns the number of key/value pairs in the object.

        Returns
        - the number of key/value pairs in the object.

        Since
        - 2.7
        """
        ...


    def isEmpty(self) -> bool:
        """
        Returns True if the number of key/value pairs in the object is zero.

        Returns
        - True if the number of key/value pairs in the object is zero.

        Since
        - 2.10.1
        """
        ...


    def has(self, memberName: str) -> bool:
        """
        Convenience method to check if a member with the specified name is present in this object.

        Arguments
        - memberName: name of the member that is being checked for presence.

        Returns
        - True if there is a member with the specified name, False otherwise.
        """
        ...


    def get(self, memberName: str) -> "JsonElement":
        """
        Returns the member with the specified name.

        Arguments
        - memberName: name of the member that is being requested.

        Returns
        - the member matching the name, or `null` if no such member exists.
        """
        ...


    def getAsJsonPrimitive(self, memberName: str) -> "JsonPrimitive":
        """
        Convenience method to get the specified member as a JsonPrimitive.

        Arguments
        - memberName: name of the member being requested.

        Returns
        - the `JsonPrimitive` corresponding to the specified member, or `null` if no
            member with this name exists.

        Raises
        - ClassCastException: if the member is not of type `JsonPrimitive`.
        """
        ...


    def getAsJsonArray(self, memberName: str) -> "JsonArray":
        """
        Convenience method to get the specified member as a JsonArray.

        Arguments
        - memberName: name of the member being requested.

        Returns
        - the `JsonArray` corresponding to the specified member, or `null` if no
            member with this name exists.

        Raises
        - ClassCastException: if the member is not of type `JsonArray`.
        """
        ...


    def getAsJsonObject(self, memberName: str) -> "JsonObject":
        """
        Convenience method to get the specified member as a JsonObject.

        Arguments
        - memberName: name of the member being requested.

        Returns
        - the `JsonObject` corresponding to the specified member, or `null` if no
            member with this name exists.

        Raises
        - ClassCastException: if the member is not of type `JsonObject`.
        """
        ...


    def asMap(self) -> dict[str, "JsonElement"]:
        """
        Returns a mutable Map view of this `JsonObject`. Changes to the `Map` are
        visible in this `JsonObject` and the other way around.
        
        The `Map` does not permit `null` keys or values. Unlike `JsonObject`'s
        `null` handling, a NullPointerException is thrown when trying to add `null`. Use JsonNull for JSON null values.

        Returns
        - mutable `Map` view

        Since
        - 2.10
        """
        ...


    def equals(self, o: "Object") -> bool:
        """
        Returns whether the other object is equal to this. This method only considers the other object
        to be equal if it is an instance of `JsonObject` and has equal members, ignoring order.
        """
        ...


    def hashCode(self) -> int:
        """
        Returns the hash code of this object. This method calculates the hash code based on the members
        of this object, ignoring order.
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Ocelot

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Ocelot(Animals):
    """
    A wild tameable cat
    """

    def isTrusting(self) -> bool:
        """
        Checks if this ocelot trusts players.

        Returns
        - True if it trusts players
        """
        ...


    def setTrusting(self, trust: bool) -> None:
        """
        Sets if this ocelot trusts players.

        Arguments
        - trust: True if it trusts players
        """
        ...


    def getCatType(self) -> "Type":
        """
        Gets the current type of this cat.

        Returns
        - Type of the cat.

        Deprecated
        - Cats are now a separate entity.
        """
        ...


    def setCatType(self, type: "Type") -> None:
        """
        Sets the current type of this cat.

        Arguments
        - type: New type of this cat.

        Deprecated
        - Cats are now a separate entity.
        """
        ...


    class Type(Enum):
        """
        Represents the various different cat types there are.

        Deprecated
        - Cats are now a separate entity.
        """

        WILD_OCELOT = (0)
        BLACK_CAT = (1)
        RED_CAT = (2)
        SIAMESE_CAT = (3)


        def getId(self) -> int:
            """
            Gets the ID of this cat type.

            Returns
            - Type ID.

            Deprecated
            - Magic value
            """
            ...


        @staticmethod
        def getType(id: int) -> "Type":
            """
            Gets a cat type by its ID.

            Arguments
            - id: ID of the cat type to get.

            Returns
            - Resulting type, or null if not found.

            Deprecated
            - Magic value
            """
            ...



"""
Python module generated from Java source file com.google.gson.internal.bind.NumberTypeAdapter

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import Gson
from com.google.gson import JsonSyntaxException
from com.google.gson import ToNumberPolicy
from com.google.gson import ToNumberStrategy
from com.google.gson import TypeAdapter
from com.google.gson import TypeAdapterFactory
from com.google.gson.internal.bind import *
from com.google.gson.reflect import TypeToken
from com.google.gson.stream import JsonReader
from com.google.gson.stream import JsonToken
from com.google.gson.stream import JsonWriter
from java.io import IOException
from typing import Any, Callable, Iterable, Tuple


class NumberTypeAdapter(TypeAdapter):
    """
    Type adapter for Number.
    """

    @staticmethod
    def getFactory(toNumberStrategy: "ToNumberStrategy") -> "TypeAdapterFactory":
        ...


    def read(self, in: "JsonReader") -> "Number":
        ...


    def write(self, out: "JsonWriter", value: "Number") -> None:
        ...



"""
Python module generated from Java source file org.bukkit.scoreboard.RenderType

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.scoreboard import *
from typing import Any, Callable, Iterable, Tuple


class RenderType(Enum):
    """
    Controls the way in which an Objective is rendered client side.
    """

    INTEGER = 0
    """
    Display integer value.
    """
    HEARTS = 1
    """
    Display number of hearts corresponding to value.
    """



"""
Python module generated from Java source file org.bukkit.persistence.PersistentDataAdapterContext

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.persistence import *
from typing import Any, Callable, Iterable, Tuple


class PersistentDataAdapterContext:
    """
    This interface represents the context in which the PersistentDataType can
    serialize and deserialize the passed values.
    """

    def newPersistentDataContainer(self) -> "PersistentDataContainer":
        """
        Creates a new and empty meta container instance.

        Returns
        - the fresh container instance
        """
        ...



"""
Python module generated from Java source file net.md_5.bungee.api.chat.Keybinds

Java source file obtained from artifact bungeecord-chat version 1.20-R0.2-20240119.213604-65

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from net.md_5.bungee.api.chat import *
from typing import Any, Callable, Iterable, Tuple


class Keybinds:
    """
    All keybind values supported by vanilla Minecraft.
    
    Values may be removed if they are no longer supported.

    See
    - KeybindComponent
    """

    JUMP = "key.jump"
    SNEAK = "key.sneak"
    SPRINT = "key.sprint"
    LEFT = "key.left"
    RIGHT = "key.right"
    BACK = "key.back"
    FORWARD = "key.forward"
    ATTACK = "key.attack"
    PICK_ITEM = "key.pickItem"
    USE = "key.use"
    DROP = "key.drop"
    HOTBAR_1 = "key.hotbar.1"
    HOTBAR_2 = "key.hotbar.2"
    HOTBAR_3 = "key.hotbar.3"
    HOTBAR_4 = "key.hotbar.4"
    HOTBAR_5 = "key.hotbar.5"
    HOTBAR_6 = "key.hotbar.6"
    HOTBAR_7 = "key.hotbar.7"
    HOTBAR_8 = "key.hotbar.8"
    HOTBAR_9 = "key.hotbar.9"
    INVENTORY = "key.inventory"
    SWAP_HANDS = "key.swapHands"
    LOAD_TOOLBAR_ACTIVATOR = "key.loadToolbarActivator"
    SAVE_TOOLBAR_ACTIVATOR = "key.saveToolbarActivator"
    PLAYERLIST = "key.playerlist"
    CHAT = "key.chat"
    COMMAND = "key.command"
    SOCIAL_INTERACTIONS = "key.socialInteractions"
    ADVANCEMENTS = "key.advancements"
    SPECTATOR_OUTLINES = "key.spectatorOutlines"
    SCREENSHOT = "key.screenshot"
    SMOOTH_CAMERA = "key.smoothCamera"
    FULLSCREEN = "key.fullscreen"
    TOGGLE_PERSPECTIVE = "key.togglePerspective"



"""
Python module generated from Java source file net.md_5.bungee.api.chat.ClickEvent

Java source file obtained from artifact bungeecord-chat version 1.20-R0.2-20240119.213604-65

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from net.md_5.bungee.api.chat import *
from typing import Any, Callable, Iterable, Tuple


class ClickEvent:

    class Action(Enum):

        OPEN_URL = 0
        """
        Open a url at the path given by
        net.md_5.bungee.api.chat.ClickEvent.value.
        """
        OPEN_FILE = 1
        """
        Open a file at the path given by
        net.md_5.bungee.api.chat.ClickEvent.value.
        """
        RUN_COMMAND = 2
        """
        Run the command given by
        net.md_5.bungee.api.chat.ClickEvent.value.
        """
        SUGGEST_COMMAND = 3
        """
        Inserts the string given by
        net.md_5.bungee.api.chat.ClickEvent.value into the player's
        text box.
        """
        CHANGE_PAGE = 4
        """
        Change to the page number given by
        net.md_5.bungee.api.chat.ClickEvent.value in a book.
        """
        COPY_TO_CLIPBOARD = 5
        """
        Copy the string given by
        net.md_5.bungee.api.chat.ClickEvent.value into the player's
        clipboard.
        """



"""
Python module generated from Java source file org.bukkit.inventory.meta.FireworkMeta

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import FireworkEffect
from org.bukkit import Material
from org.bukkit.inventory.meta import *
from typing import Any, Callable, Iterable, Tuple


class FireworkMeta(ItemMeta):
    """
    Represents a Material.FIREWORK_ROCKET and its effects.
    """

    def addEffect(self, effect: "FireworkEffect") -> None:
        """
        Add another effect to this firework.

        Arguments
        - effect: The firework effect to add

        Raises
        - IllegalArgumentException: If effect is null
        """
        ...


    def addEffects(self, *effects: Tuple["FireworkEffect", ...]) -> None:
        """
        Add several effects to this firework.

        Arguments
        - effects: The firework effects to add

        Raises
        - IllegalArgumentException: If effects is null
        - IllegalArgumentException: If any effect is null (may be thrown
            after changes have occurred)
        """
        ...


    def addEffects(self, effects: Iterable["FireworkEffect"]) -> None:
        """
        Add several firework effects to this firework.

        Arguments
        - effects: An iterable object whose iterator yields the desired
            firework effects

        Raises
        - IllegalArgumentException: If effects is null
        - IllegalArgumentException: If any effect is null (may be thrown
            after changes have occurred)
        """
        ...


    def getEffects(self) -> list["FireworkEffect"]:
        """
        Get the effects in this firework.

        Returns
        - An immutable list of the firework effects
        """
        ...


    def getEffectsSize(self) -> int:
        """
        Get the number of effects in this firework.

        Returns
        - The number of effects
        """
        ...


    def removeEffect(self, index: int) -> None:
        """
        Remove an effect from this firework.

        Arguments
        - index: The index of the effect to remove

        Raises
        - IndexOutOfBoundsException: If index < 0 or index > .getEffectsSize()
        """
        ...


    def clearEffects(self) -> None:
        """
        Remove all effects from this firework.
        """
        ...


    def hasEffects(self) -> bool:
        """
        Get whether this firework has any effects.

        Returns
        - True if it has effects, False if there are no effects
        """
        ...


    def hasPower(self) -> bool:
        """
        Get whether this firework has power set by component.

        Returns
        - True if it has power set, False if there are no power set
        """
        ...


    def getPower(self) -> int:
        """
        Gets the approximate height the firework will fly.
        
        Plugins should check that hasPower() returns `True`
        before calling this method.

        Returns
        - approximate flight height of the firework.

        See
        - .hasPower()
        """
        ...


    def setPower(self, power: int) -> None:
        """
        Sets the approximate power of the firework. Each level of power is half
        a second of flight time.

        Arguments
        - power: the power of the firework, from 0-255

        Raises
        - IllegalArgumentException: if power<0 or power>255
        """
        ...


    def clone(self) -> "FireworkMeta":
        ...



"""
Python module generated from Java source file org.bukkit.spawner.TrialSpawnerConfiguration

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.loot import LootTable
from org.bukkit.spawner import *
from typing import Any, Callable, Iterable, Tuple


class TrialSpawnerConfiguration(BaseSpawner):
    """
    Represents one of the configurations of a trial spawner.
    """

    def getBaseSpawnsBeforeCooldown(self) -> float:
        """
        Gets the base number of entities the spawner will spawn before going into
        cooldown.

        Returns
        - the number of entities
        """
        ...


    def setBaseSpawnsBeforeCooldown(self, amount: float) -> None:
        """
        Sets the base number of entities the spawner will spawn before going into
        cooldown.

        Arguments
        - amount: the number of entities
        """
        ...


    def getBaseSimultaneousEntities(self) -> float:
        """
        Gets the base number of entities this spawner can track at once. 
        If the limit is reached the spawner will not be able to spawn any more
        entities until the existing entities are killed or move too far away.

        Returns
        - the number of entities
        """
        ...


    def setBaseSimultaneousEntities(self, amount: float) -> None:
        """
        Sets the base number of entities this spawner can track at once. 
        If the limit is reached the spawner will not be able to spawn any more
        entities until the existing entities are killed or move too far away.

        Arguments
        - amount: the number of entities
        """
        ...


    def getAdditionalSpawnsBeforeCooldown(self) -> float:
        """
        Gets the additional number of entities the spawner will spawn per tracked player
        before going into cooldown.

        Returns
        - the number of entities
        """
        ...


    def setAdditionalSpawnsBeforeCooldown(self, amount: float) -> None:
        """
        Sets the additional number of entities the spawner will spawn per tracked player
        before going into cooldown.

        Arguments
        - amount: the number of entities
        """
        ...


    def getAdditionalSimultaneousEntities(self) -> float:
        """
        Gets the additional number of entities this spawner can track at once per
        tracked player. 
        If the limit is reached the spawner will not be able to spawn any more
        entities until the existing entities are killed or move too far away.

        Returns
        - the number of entities
        """
        ...


    def setAdditionalSimultaneousEntities(self, amount: float) -> None:
        """
        Sets the additional number of entities this spawner can track at once per
        tracked player. 
        If the limit is reached the spawner will not be able to spawn any more
        entities until the existing entities are killed or move too far away.

        Arguments
        - amount: the number of entities
        """
        ...


    def getPossibleRewards(self) -> dict["LootTable", "Integer"]:
        """
        Gets a list of LootTables this spawner can pick a reward from as
        well as their associated weight to be chosen.

        Returns
        - a map of loot tables and their associated weight, or an empty
                map if there are none
        """
        ...


    def addPossibleReward(self, table: "LootTable", weight: int) -> None:
        """
        Add a LootTable to the list of tables this spawner can pick a reward
        from with a given weight.

        Arguments
        - table: the loot table
        - weight: the weight, must be at least 1
        """
        ...


    def removePossibleReward(self, table: "LootTable") -> None:
        """
        Removes the provided LootTable from the list of tables this spawner
        can pick a reward from.

        Arguments
        - table: the loot table
        """
        ...


    def setPossibleRewards(self, rewards: dict["LootTable", "Integer"]) -> None:
        """
        Sets the list of LootTables and their weights this spawner can pick a
        reward from. 
        All loot tables in the map must be non-null and all weights must be at least
        1.

        Arguments
        - rewards: a map of loot tables and their weights, or null to clear all
                       possible tables
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableSet

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.collect import *
from com.google.common.math import IntMath
from com.google.common.primitives import Ints
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations.concurrent import LazyInit
from com.google.j2objc.annotations import RetainedWith
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import Serializable
from java.math import RoundingMode
from java.util import Arrays
from java.util import Collections
from java.util import EnumSet
from java.util import Iterator
from java.util import SortedSet
from java.util import Spliterator
from java.util.function import Consumer
from java.util.stream import Collector
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ImmutableSet(ImmutableCollection, Set):
    """
    A Set whose contents will never change, with many other important properties detailed at
    ImmutableCollection.

    Since
    - 2.0
    """

    @staticmethod
    def toImmutableSet() -> "Collector"["E", Any, "ImmutableSet"["E"]]:
        """
        Returns a `Collector` that accumulates the input elements into a new `ImmutableSet`. Elements appear in the resulting set in the encounter order of the stream; if
        the stream contains duplicates (according to Object.equals(Object)), only the first
        duplicate in encounter order will appear in the result.

        Since
        - 21.0
        """
        ...


    @staticmethod
    def of() -> "ImmutableSet"["E"]:
        """
        Returns the empty immutable set. Preferred over Collections.emptySet for code
        consistency, and because the return type conveys the immutability guarantee.
        
        **Performance note:** the instance returned is a singleton.
        """
        ...


    @staticmethod
    def of(e1: "E") -> "ImmutableSet"["E"]:
        """
        Returns an immutable set containing the given element. Preferred over Collections.singleton for code consistency, `null` rejection, and because the return
        type conveys the immutability guarantee.
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E") -> "ImmutableSet"["E"]:
        """
        Returns an immutable set containing the given elements, minus duplicates, in the order each was
        first specified. That is, if multiple elements are Object.equals equal, all except
        the first are ignored.
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E") -> "ImmutableSet"["E"]:
        """
        Returns an immutable set containing the given elements, minus duplicates, in the order each was
        first specified. That is, if multiple elements are Object.equals equal, all except
        the first are ignored.
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E") -> "ImmutableSet"["E"]:
        """
        Returns an immutable set containing the given elements, minus duplicates, in the order each was
        first specified. That is, if multiple elements are Object.equals equal, all except
        the first are ignored.
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E") -> "ImmutableSet"["E"]:
        """
        Returns an immutable set containing the given elements, minus duplicates, in the order each was
        first specified. That is, if multiple elements are Object.equals equal, all except
        the first are ignored.
        """
        ...


    @staticmethod
    def of(e1: "E", e2: "E", e3: "E", e4: "E", e5: "E", e6: "E", *others: Tuple["E", ...]) -> "ImmutableSet"["E"]:
        """
        Returns an immutable set containing the given elements, minus duplicates, in the order each was
        first specified. That is, if multiple elements are Object.equals equal, all except
        the first are ignored.
        
        The array `others` must not be longer than `Integer.MAX_VALUE - 6`.

        Since
        - 3.0 (source-compatible since 2.0)
        """
        ...


    @staticmethod
    def copyOf(elements: Iterable["E"]) -> "ImmutableSet"["E"]:
        ...


    @staticmethod
    def copyOf(elements: Iterable["E"]) -> "ImmutableSet"["E"]:
        """
        Returns an immutable set containing each of `elements`, minus duplicates, in the order
        each appears first in the source iterable. This method iterates over `elements` only
        once.
        
        **Performance note:** This method will sometimes recognize that the actual copy operation
        is unnecessary; for example, `copyOf(copyOf(anArrayList))` should copy the data only
        once. This reduces the expense of habitually making defensive copies at API boundaries.
        However, the precise conditions for skipping the copy operation are undefined.

        Raises
        - NullPointerException: if any of `elements` is null
        """
        ...


    @staticmethod
    def copyOf(elements: Iterator["E"]) -> "ImmutableSet"["E"]:
        """
        Returns an immutable set containing each of `elements`, minus duplicates, in the order
        each appears first in the source iterator.

        Raises
        - NullPointerException: if any of `elements` is null
        """
        ...


    @staticmethod
    def copyOf(elements: list["E"]) -> "ImmutableSet"["E"]:
        """
        Returns an immutable set containing each of `elements`, minus duplicates, in the order
        each appears first in the source array.

        Raises
        - NullPointerException: if any of `elements` is null

        Since
        - 3.0
        """
        ...


    def equals(self, object: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...


    def iterator(self) -> "UnmodifiableIterator"["E"]:
        ...


    @staticmethod
    def builder() -> "Builder"["E"]:
        """
        Returns a new builder. The generated builder is equivalent to the builder created by the Builder constructor.
        """
        ...


    @staticmethod
    def builderWithExpectedSize(expectedSize: int) -> "Builder"["E"]:
        """
        Returns a new builder, expecting the specified number of distinct elements to be added.
        
        If `expectedSize` is exactly the number of distinct elements added to the builder
        before Builder.build is called, the builder is likely to perform better than an unsized
        .builder() would have.
        
        It is not specified if any performance benefits apply if `expectedSize` is close to,
        but not exactly, the number of distinct elements added to the builder.

        Since
        - 23.1
        """
        ...


    class Builder(Builder):
        """
        A builder for creating `ImmutableSet` instances. Example:
        
        ````static final ImmutableSet<Color> GOOGLE_COLORS =
            ImmutableSet.<Color>builder()
                .addAll(WEBSAFE_COLORS)
                .add(new Color(0, 191, 255))
                .build();````
        
        Elements appear in the resulting set in the same order they were first added to the builder.
        
        Building does not change the state of the builder, so it is still possible to add more
        elements and to build again.

        Since
        - 2.0
        """

        def __init__(self):
            ...


        def add(self, element: "E") -> "Builder"["E"]:
            ...


        def add(self, *elements: Tuple["E", ...]) -> "Builder"["E"]:
            ...


        def addAll(self, elements: Iterable["E"]) -> "Builder"["E"]:
            """
            Adds each element of `elements` to the `ImmutableSet`, ignoring duplicate
            elements (only the first duplicate element is added).

            Arguments
            - elements: the elements to add

            Returns
            - this `Builder` object

            Raises
            - NullPointerException: if `elements` is null or contains a null element
            """
            ...


        def addAll(self, elements: Iterator["E"]) -> "Builder"["E"]:
            ...


        def build(self) -> "ImmutableSet"["E"]:
            ...



"""
Python module generated from Java source file org.bukkit.event.entity.PlayerDeathEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.damage import DamageSource
from org.bukkit.entity import Player
from org.bukkit.event.entity import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class PlayerDeathEvent(EntityDeathEvent):
    """
    Thrown whenever a Player dies
    """

    def __init__(self, player: "Player", damageSource: "DamageSource", drops: list["ItemStack"], droppedExp: int, deathMessage: str):
        ...


    def __init__(self, player: "Player", damageSource: "DamageSource", drops: list["ItemStack"], droppedExp: int, newExp: int, deathMessage: str):
        ...


    def __init__(self, player: "Player", damageSource: "DamageSource", drops: list["ItemStack"], droppedExp: int, newExp: int, newTotalExp: int, newLevel: int, deathMessage: str):
        ...


    def getEntity(self) -> "Player":
        ...


    def setDeathMessage(self, deathMessage: str) -> None:
        """
        Set the death message that will appear to everyone on the server.

        Arguments
        - deathMessage: Message to appear to other players on the server.
        """
        ...


    def getDeathMessage(self) -> str:
        """
        Get the death message that will appear to everyone on the server.

        Returns
        - Message to appear to other players on the server.
        """
        ...


    def getNewExp(self) -> int:
        """
        Gets how much EXP the Player should have at respawn.
        
        This does not indicate how much EXP should be dropped, please see
        .getDroppedExp() for that.

        Returns
        - New EXP of the respawned player
        """
        ...


    def setNewExp(self, exp: int) -> None:
        """
        Sets how much EXP the Player should have at respawn.
        
        This does not indicate how much EXP should be dropped, please see
        .setDroppedExp(int) for that.

        Arguments
        - exp: New EXP of the respawned player
        """
        ...


    def getNewLevel(self) -> int:
        """
        Gets the Level the Player should have at respawn.

        Returns
        - New Level of the respawned player
        """
        ...


    def setNewLevel(self, level: int) -> None:
        """
        Sets the Level the Player should have at respawn.

        Arguments
        - level: New Level of the respawned player
        """
        ...


    def getNewTotalExp(self) -> int:
        """
        Gets the Total EXP the Player should have at respawn.

        Returns
        - New Total EXP of the respawned player
        """
        ...


    def setNewTotalExp(self, totalExp: int) -> None:
        """
        Sets the Total EXP the Player should have at respawn.

        Arguments
        - totalExp: New Total EXP of the respawned player
        """
        ...


    def getKeepLevel(self) -> bool:
        """
        Gets if the Player should keep all EXP at respawn.
        
        This flag overrides other EXP settings

        Returns
        - True if Player should keep all pre-death exp
        """
        ...


    def setKeepLevel(self, keepLevel: bool) -> None:
        """
        Sets if the Player should keep all EXP at respawn.
        
        This overrides all other EXP settings
        
        **This doesn't prevent the EXP from dropping.
        .setDroppedExp(int) should be used stop the
        EXP from dropping.**

        Arguments
        - keepLevel: True to keep all current value levels
        """
        ...


    def setKeepInventory(self, keepInventory: bool) -> None:
        """
        Sets if the Player keeps inventory on death.
        
        **This doesn't prevent the items from dropping.
        `getDrops().clear()` should be used stop the
        items from dropping.**

        Arguments
        - keepInventory: True to keep the inventory
        """
        ...


    def getKeepInventory(self) -> bool:
        """
        Gets if the Player keeps inventory on death.

        Returns
        - True if the player keeps inventory on death
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.Table

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Objects
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import CompatibleWith
from com.google.errorprone.annotations import DoNotMock
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Table:
    """
    A collection that associates an ordered pair of keys, called a row key and a column key, with a
    single value. A table may be sparse, with only a small fraction of row key / column key pairs
    possessing a corresponding value.
    
    The mappings corresponding to a given row key may be viewed as a Map whose keys are
    the columns. The reverse is also available, associating a column with a row key / value map. Note
    that, in some implementations, data access by column key may have fewer supported operations or
    worse performance than data access by row key.
    
    The methods returning collections or maps always return views of the underlying table.
    Updating the table can change the contents of those collections, and updating the collections
    will change the table.
    
    All methods that modify the table are optional, and the views returned by the table may or may
    not be modifiable. When modification isn't supported, those methods will throw an UnsupportedOperationException.
    
    <h3>Implementations</h3>
    
    
      - ImmutableTable
      - HashBasedTable
      - TreeBasedTable
      - ArrayTable
      - Tables.newCustomTable Tables.newCustomTable
    
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/NewCollectionTypesExplained#table">`Table`</a>.
    
    Type `<R>`: the type of the table row keys
    
    Type `<C>`: the type of the table column keys
    
    Type `<V>`: the type of the mapped values

    Author(s)
    - Jared Levy

    Since
    - 7.0
    """

    def contains(self, rowKey: "Object", columnKey: "Object") -> bool:
        """
        Returns `True` if the table contains a mapping with the specified row and column keys.

        Arguments
        - rowKey: key of row to search for
        - columnKey: key of column to search for
        """
        ...


    def containsRow(self, rowKey: "Object") -> bool:
        """
        Returns `True` if the table contains a mapping with the specified row key.

        Arguments
        - rowKey: key of row to search for
        """
        ...


    def containsColumn(self, columnKey: "Object") -> bool:
        """
        Returns `True` if the table contains a mapping with the specified column.

        Arguments
        - columnKey: key of column to search for
        """
        ...


    def containsValue(self, value: "Object") -> bool:
        """
        Returns `True` if the table contains a mapping with the specified value.

        Arguments
        - value: value to search for
        """
        ...


    def get(self, rowKey: "Object", columnKey: "Object") -> "V":
        """
        Returns the value corresponding to the given row and column keys, or `null` if no such
        mapping exists.

        Arguments
        - rowKey: key of row to search for
        - columnKey: key of column to search for
        """
        ...


    def isEmpty(self) -> bool:
        """
        Returns `True` if the table contains no mappings.
        """
        ...


    def size(self) -> int:
        """
        Returns the number of row key / column key / value mappings in the table.
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Compares the specified object with this table for equality. Two tables are equal when their
        cell views, as returned by .cellSet, are equal.
        """
        ...


    def hashCode(self) -> int:
        """
        Returns the hash code for this table. The hash code of a table is defined as the hash code of
        its cell view, as returned by .cellSet.
        """
        ...


    def clear(self) -> None:
        """
        Removes all mappings from the table.
        """
        ...


    def put(self, rowKey: "R", columnKey: "C", value: "V") -> "V":
        """
        Associates the specified value with the specified keys. If the table already contained a
        mapping for those keys, the old value is replaced with the specified value.

        Arguments
        - rowKey: row key that the value should be associated with
        - columnKey: column key that the value should be associated with
        - value: value to be associated with the specified keys

        Returns
        - the value previously associated with the keys, or `null` if no mapping existed
            for the keys
        """
        ...


    def putAll(self, table: "Table"["R", "C", "V"]) -> None:
        """
        Copies all mappings from the specified table to this table. The effect is equivalent to calling
        .put with each row key / column key / value mapping in `table`.

        Arguments
        - table: the table to add to this table
        """
        ...


    def remove(self, rowKey: "Object", columnKey: "Object") -> "V":
        """
        Removes the mapping, if any, associated with the given keys.

        Arguments
        - rowKey: row key of mapping to be removed
        - columnKey: column key of mapping to be removed

        Returns
        - the value previously associated with the keys, or `null` if no such value existed
        """
        ...


    def row(self, rowKey: "R") -> dict["C", "V"]:
        """
        Returns a view of all mappings that have the given row key. For each row key / column key /
        value mapping in the table with that row key, the returned map associates the column key with
        the value. If no mappings in the table have the provided row key, an empty map is returned.
        
        Changes to the returned map will update the underlying table, and vice versa.

        Arguments
        - rowKey: key of row to search for in the table

        Returns
        - the corresponding map from column keys to values
        """
        ...


    def column(self, columnKey: "C") -> dict["R", "V"]:
        """
        Returns a view of all mappings that have the given column key. For each row key / column key /
        value mapping in the table with that column key, the returned map associates the row key with
        the value. If no mappings in the table have the provided column key, an empty map is returned.
        
        Changes to the returned map will update the underlying table, and vice versa.

        Arguments
        - columnKey: key of column to search for in the table

        Returns
        - the corresponding map from row keys to values
        """
        ...


    def cellSet(self) -> set["Cell"["R", "C", "V"]]:
        """
        Returns a set of all row key / column key / value triplets. Changes to the returned set will
        update the underlying table, and vice versa. The cell set does not support the `add` or
        `addAll` methods.

        Returns
        - set of table cells consisting of row key / column key / value triplets
        """
        ...


    def rowKeySet(self) -> set["R"]:
        """
        Returns a set of row keys that have one or more values in the table. Changes to the set will
        update the underlying table, and vice versa.

        Returns
        - set of row keys
        """
        ...


    def columnKeySet(self) -> set["C"]:
        """
        Returns a set of column keys that have one or more values in the table. Changes to the set will
        update the underlying table, and vice versa.

        Returns
        - set of column keys
        """
        ...


    def values(self) -> Iterable["V"]:
        """
        Returns a collection of all values, which may contain duplicates. Changes to the returned
        collection will update the underlying table, and vice versa.

        Returns
        - collection of values
        """
        ...


    def rowMap(self) -> dict["R", dict["C", "V"]]:
        """
        Returns a view that associates each row key with the corresponding map from column keys to
        values. Changes to the returned map will update this table. The returned map does not support
        `put()` or `putAll()`, or `setValue()` on its entries.
        
        In contrast, the maps returned by `rowMap().get()` have the same behavior as those
        returned by .row. Those maps may support `setValue()`, `put()`, and `putAll()`.

        Returns
        - a map view from each row key to a secondary map from column keys to values
        """
        ...


    def columnMap(self) -> dict["C", dict["R", "V"]]:
        """
        Returns a view that associates each column key with the corresponding map from row keys to
        values. Changes to the returned map will update this table. The returned map does not support
        `put()` or `putAll()`, or `setValue()` on its entries.
        
        In contrast, the maps returned by `columnMap().get()` have the same behavior as those
        returned by .column. Those maps may support `setValue()`, `put()`, and
        `putAll()`.

        Returns
        - a map view from each column key to a secondary map from row keys to values
        """
        ...



"""
Python module generated from Java source file net.md_5.bungee.api.chat.ComponentBuilder

Java source file obtained from artifact bungeecord-chat version 1.20-R0.2-20240119.213604-65

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from enum import Enum
from net.md_5.bungee.api import ChatColor
from net.md_5.bungee.api.chat import *
from typing import Any, Callable, Iterable, Tuple


class ComponentBuilder:
    """
    
    ComponentBuilder simplifies creating basic messages by allowing the use of a
    chainable builder.
    
    ```
    new ComponentBuilder("Hello ").color(ChatColor.RED).
    append("World").color(ChatColor.BLUE). append("!").bold(True).create();
    ```
    
    All methods (excluding .append(String) and .create() work on
    the last part appended to the builder, so in the example above "Hello " would
    be net.md_5.bungee.api.ChatColor.RED and "World" would be
    net.md_5.bungee.api.ChatColor.BLUE but "!" would be bold and
    net.md_5.bungee.api.ChatColor.BLUE because append copies the previous
    part's formatting
    """

    def __init__(self, original: "ComponentBuilder"):
        """
        Creates a ComponentBuilder from the other given ComponentBuilder to clone
        it.

        Arguments
        - original: the original for the new ComponentBuilder.
        """
        ...


    def __init__(self, text: str):
        """
        Creates a ComponentBuilder with the given text as the first part.

        Arguments
        - text: the first text element
        """
        ...


    def __init__(self, component: "BaseComponent"):
        """
        Creates a ComponentBuilder with the given component as the first part.

        Arguments
        - component: the first component element
        """
        ...


    def resetCursor(self) -> "ComponentBuilder":
        """
        Resets the cursor to index of the last element.

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def setCursor(self, pos: int) -> "ComponentBuilder":
        """
        Sets the position of the current component to be modified

        Arguments
        - pos: the cursor position synonymous to an element position for a
        list

        Returns
        - this ComponentBuilder for chaining

        Raises
        - IndexOutOfBoundsException: if the index is out of range
        (`index < 0 || index >= size()`)
        """
        ...


    def append(self, component: "BaseComponent") -> "ComponentBuilder":
        """
        Appends a component to the builder and makes it the current target for
        formatting. The component will have all the formatting from previous
        part.

        Arguments
        - component: the component to append

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def append(self, component: "BaseComponent", retention: "FormatRetention") -> "ComponentBuilder":
        """
        Appends a component to the builder and makes it the current target for
        formatting. You can specify the amount of formatting retained from
        previous part.

        Arguments
        - component: the component to append
        - retention: the formatting to retain

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def append(self, components: list["BaseComponent"]) -> "ComponentBuilder":
        """
        Appends the components to the builder and makes the last element the
        current target for formatting. The components will have all the
        formatting from previous part.

        Arguments
        - components: the components to append

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def append(self, components: list["BaseComponent"], retention: "FormatRetention") -> "ComponentBuilder":
        """
        Appends the components to the builder and makes the last element the
        current target for formatting. You can specify the amount of formatting
        retained from previous part.

        Arguments
        - components: the components to append
        - retention: the formatting to retain

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def append(self, translatable: "TranslationProvider") -> "ComponentBuilder":
        """
        Appends the TranslationProvider object to the builder and makes
        the last element the current target for formatting. The components will
        have all the formatting from previous part.

        Arguments
        - translatable: the translatable object to append

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def append(self, translatable: "TranslationProvider", retention: "FormatRetention") -> "ComponentBuilder":
        """
        Appends the TranslationProvider object to the builder and makes
        the last element the current target for formatting. You can specify the
        amount of formatting retained from previous part.

        Arguments
        - translatable: the translatable object to append
        - retention: the formatting to retain

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def append(self, text: str) -> "ComponentBuilder":
        """
        Appends the text to the builder and makes it the current target for
        formatting. The text will have all the formatting from previous part.

        Arguments
        - text: the text to append

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def appendLegacy(self, text: str) -> "ComponentBuilder":
        """
        Parse text to BaseComponent[] with colors and format, appends the text to
        the builder and makes it the current target for formatting. The component
        will have all the formatting from previous part.

        Arguments
        - text: the text to append

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def append(self, text: str, retention: "FormatRetention") -> "ComponentBuilder":
        """
        Appends the text to the builder and makes it the current target for
        formatting. You can specify the amount of formatting retained from
        previous part.

        Arguments
        - text: the text to append
        - retention: the formatting to retain

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def append(self, joiner: "Joiner") -> "ComponentBuilder":
        """
        Allows joining additional components to this builder using the given
        Joiner and FormatRetention.ALL.
        
        Simply executes the provided joiner on this instance to facilitate a
        chain pattern.

        Arguments
        - joiner: joiner used for operation

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def append(self, joiner: "Joiner", retention: "FormatRetention") -> "ComponentBuilder":
        """
        Allows joining additional components to this builder using the given
        Joiner.
        
        Simply executes the provided joiner on this instance to facilitate a
        chain pattern.

        Arguments
        - joiner: joiner used for operation
        - retention: the formatting to retain

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def removeComponent(self, pos: int) -> None:
        """
        Remove the component part at the position of given index.

        Arguments
        - pos: the index to remove at

        Raises
        - IndexOutOfBoundsException: if the index is out of range
        (`index < 0 || index >= size()`)
        """
        ...


    def getComponent(self, pos: int) -> "BaseComponent":
        """
        Gets the component part at the position of given index.

        Arguments
        - pos: the index to find

        Returns
        - the component

        Raises
        - IndexOutOfBoundsException: if the index is out of range
        (`index < 0 || index >= size()`)
        """
        ...


    def getCurrentComponent(self) -> "BaseComponent":
        """
        Gets the component at the position of the cursor.

        Returns
        - the active component or null if builder is empty
        """
        ...


    def color(self, color: "ChatColor") -> "ComponentBuilder":
        """
        Sets the color of the current part.

        Arguments
        - color: the new color

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def font(self, font: str) -> "ComponentBuilder":
        """
        Sets the font of the current part.

        Arguments
        - font: the new font

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def bold(self, bold: bool) -> "ComponentBuilder":
        """
        Sets whether the current part is bold.

        Arguments
        - bold: whether this part is bold

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def italic(self, italic: bool) -> "ComponentBuilder":
        """
        Sets whether the current part is italic.

        Arguments
        - italic: whether this part is italic

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def underlined(self, underlined: bool) -> "ComponentBuilder":
        """
        Sets whether the current part is underlined.

        Arguments
        - underlined: whether this part is underlined

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def strikethrough(self, strikethrough: bool) -> "ComponentBuilder":
        """
        Sets whether the current part is strikethrough.

        Arguments
        - strikethrough: whether this part is strikethrough

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def obfuscated(self, obfuscated: bool) -> "ComponentBuilder":
        """
        Sets whether the current part is obfuscated.

        Arguments
        - obfuscated: whether this part is obfuscated

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def style(self, style: "ComponentStyle") -> "ComponentBuilder":
        """
        Applies the provided ComponentStyle to the current part.

        Arguments
        - style: the style to apply

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def insertion(self, insertion: str) -> "ComponentBuilder":
        """
        Sets the insertion text for the current part.

        Arguments
        - insertion: the insertion text

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def event(self, clickEvent: "ClickEvent") -> "ComponentBuilder":
        """
        Sets the click event for the current part.

        Arguments
        - clickEvent: the click event

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def event(self, hoverEvent: "HoverEvent") -> "ComponentBuilder":
        """
        Sets the hover event for the current part.

        Arguments
        - hoverEvent: the hover event

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def reset(self) -> "ComponentBuilder":
        """
        Sets the current part back to normal settings. Only text is kept.

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def retain(self, retention: "FormatRetention") -> "ComponentBuilder":
        """
        Retains only the specified formatting. Text is not modified.

        Arguments
        - retention: the formatting to retain

        Returns
        - this ComponentBuilder for chaining
        """
        ...


    def build(self) -> "BaseComponent":
        """
        Returns the component built by this builder. If this builder is empty, an
        empty text component will be returned.

        Returns
        - the component
        """
        ...


    def create(self) -> list["BaseComponent"]:
        """
        Returns the components needed to display the message created by this
        builder.git
        
        <strong>NOTE:</strong> .build() is preferred as it will
        consolidate all components into a single BaseComponent with extra
        contents as opposed to an array of components which is non-standard and
        may result in unexpected behavior.

        Returns
        - the created components
        """
        ...


    class Joiner:
        """
        Functional interface to join additional components to a ComponentBuilder.
        """

        def join(self, componentBuilder: "ComponentBuilder", retention: "FormatRetention") -> "ComponentBuilder":
            """
            Joins additional components to the provided ComponentBuilder
            and then returns it to fulfill a chain pattern.
            
            Retention may be ignored and is to be understood as an optional
            recommendation to the Joiner and not as a guarantee to have a
            previous component in builder unmodified.

            Arguments
            - componentBuilder: to which to append additional components
            - retention: the formatting to possibly retain

            Returns
            - input componentBuilder for chaining
            """
            ...


    class FormatRetention(Enum):

        NONE = 0
        """
        Specify that we do not want to retain anything from the previous
        component.
        """
        FORMATTING = 1
        """
        Specify that we want the formatting retained from the previous
        component.
        """
        EVENTS = 2
        """
        Specify that we want the events retained from the previous component.
        """
        ALL = 3
        """
        Specify that we want to retain everything from the previous
        component.
        """



"""
Python module generated from Java source file com.google.common.collect.EmptyContiguousSet

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import Serializable
from java.util import NoSuchElementException
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class EmptyContiguousSet(ContiguousSet):
    """
    An empty contiguous set.

    Author(s)
    - Gregory Kick
    """

    def first(self) -> "C":
        ...


    def last(self) -> "C":
        ...


    def size(self) -> int:
        ...


    def intersection(self, other: "ContiguousSet"["C"]) -> "ContiguousSet"["C"]:
        ...


    def range(self) -> "Range"["C"]:
        ...


    def range(self, lowerBoundType: "BoundType", upperBoundType: "BoundType") -> "Range"["C"]:
        ...


    def contains(self, object: "Object") -> bool:
        ...


    def iterator(self) -> "UnmodifiableIterator"["C"]:
        ...


    def descendingIterator(self) -> "UnmodifiableIterator"["C"]:
        ...


    def isEmpty(self) -> bool:
        ...


    def asList(self) -> "ImmutableList"["C"]:
        ...


    def toString(self) -> str:
        ...


    def equals(self, object: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...



"""
Python module generated from Java source file com.google.common.base.CommonPattern

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import *
from typing import Any, Callable, Iterable, Tuple


class CommonPattern:
    """
    The subset of the java.util.regex.Pattern API which is used by this package, and also
    shared with the `re2j` library. For internal use only. Please refer to the `Pattern`
    javadoc for details.
    """

    def matcher(self, t: "CharSequence") -> "CommonMatcher":
        ...


    def pattern(self) -> str:
        ...


    def flags(self) -> int:
        ...


    def toString(self) -> str:
        ...


    @staticmethod
    def compile(pattern: str) -> "CommonPattern":
        ...


    @staticmethod
    def isPcreLike() -> bool:
        ...



from .StandardCharsets import StandardCharsets
from .Charset import Charset
from .IllegalCharsetNameException import IllegalCharsetNameException
from .UnsupportedCharsetException import UnsupportedCharsetException
from .CharsetEncoder import CharsetEncoder
from .CoderResult import CoderResult
from .CodingErrorAction import CodingErrorAction
from .CharacterCodingException import CharacterCodingException
from .CharsetDecoder import CharsetDecoder


"""
Python module generated from Java source file org.bukkit.conversations.ConversationCanceller

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.conversations import *
from typing import Any, Callable, Iterable, Tuple


class ConversationCanceller(Cloneable):
    """
    A ConversationCanceller is a class that cancels an active Conversation. A Conversation can have more than one ConversationCanceller.
    """

    def setConversation(self, conversation: "Conversation") -> None:
        """
        Sets the conversation this ConversationCanceller can optionally cancel.

        Arguments
        - conversation: A conversation.
        """
        ...


    def cancelBasedOnInput(self, context: "ConversationContext", input: str) -> bool:
        """
        Cancels a conversation based on user input.

        Arguments
        - context: Context information about the conversation.
        - input: The input text from the user.

        Returns
        - True to cancel the conversation, False otherwise.
        """
        ...


    def clone(self) -> "ConversationCanceller":
        """
        Allows the ConversationFactory to duplicate this
        ConversationCanceller when creating a new Conversation.
        
        Implementing this method should reset any internal object state.

        Returns
        - A clone.
        """
        ...



"""
Python module generated from Java source file org.bukkit.profile.PlayerProfile

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import UUID
from java.util.concurrent import CompletableFuture
from org.bukkit import Server
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.profile import *
from typing import Any, Callable, Iterable, Tuple


class PlayerProfile(Cloneable, ConfigurationSerializable):
    """
    A player profile.
    
    A player profile always provides a unique id, a non-empty name, or both. Its
    unique id and name are immutable, but other properties (such as its textures)
    can be altered.
    
    New profiles can be created via
    Server.createPlayerProfile(UUID, String).
    """

    def getUniqueId(self) -> "UUID":
        """
        Gets the player's unique id.

        Returns
        - the player's unique id, or `null` if not available
        """
        ...


    def getName(self) -> str:
        """
        Gets the player name.

        Returns
        - the player name, or `null` if not available
        """
        ...


    def getTextures(self) -> "PlayerTextures":
        """
        Gets the PlayerTextures of this profile.

        Returns
        - the textures, not `null`
        """
        ...


    def setTextures(self, textures: "PlayerTextures") -> None:
        """
        Copies the given textures.

        Arguments
        - textures: the textures to copy, or `null` to clear the
        textures
        """
        ...


    def isComplete(self) -> bool:
        """
        Checks whether this profile is complete.
        
        A profile is currently considered complete if it has a name, a unique id,
        and textures.

        Returns
        - `True` if this profile is complete
        """
        ...


    def update(self) -> "CompletableFuture"["PlayerProfile"]:
        """
        Produces an updated player profile based on this profile.
        
        This tries to produce a completed profile by filling in missing
        properties (name, unique id, textures, etc.), and updates existing
        properties (e.g. name, textures, etc.) to their official and up-to-date
        values. This operation does not alter the current profile, but produces a
        new updated PlayerProfile.
        
        If no player exists for the unique id or name of this profile, this
        operation yields a profile that is equal to the current profile, which
        might not be complete.
        
        This is an asynchronous operation: Updating the profile can result in an
        outgoing connection in another thread in order to fetch the latest
        profile properties. The returned CompletableFuture will be
        completed once the updated profile is available. In order to not block
        the server's main thread, you should not wait for the result of the
        returned CompletableFuture on the server's main thread. Instead, if you
        want to do something with the updated player profile on the server's main
        thread once it is available, you could do something like this:
        ```
        profile.update().thenAcceptAsync(updatedProfile -> {
            // Do something with the updated profile:
            // ...
        }, runnable -> Bukkit.getScheduler().runTask(plugin, runnable));
        ```

        Returns
        - a completable future that gets completed with the updated
        PlayerProfile once it is available
        """
        ...


    def clone(self) -> "PlayerProfile":
        ...
